import React from 'react';
import { ConfigOptions } from './providers/ConfigProviders';
import { ThemeConfig } from './providers/CustomThemeProvider';
import { PinnedTokenProviderProps } from './providers/PinnedTokenProvider';
import { Overrides } from './providers/OverrideProvider';
/**
 * This contains all the providers that are needed for the thedefiengine components and hooks to work. Add it to the root of your app.
 * You can then import SwapCard to render the exchange widget or import any other hooks or components you need.
 *
 * @param props ConfigOptions & React.PropsWithChildren
 * @example
 * ```jsx
 * // app.jsx or index.js
 *
 * <TheDefiEngineAppProvider config={config}>
 *    // others children
 * </TheDefiEngineAppProvider>
 * ```
 */
export declare const TheDefiEngineAppProvider: ({ children, enableDarkMode, defaultPinnedTokens, overrides, ...config }: TheDefiEngineAppProviderProps) => import("react/jsx-runtime").JSX.Element;
export type TheDefiEngineAppProviderProps = React.PropsWithChildren<ThemeConfig & ConfigOptions & PinnedTokenProviderProps & {
    /**
     * Override colors and other component props
     * See https://whitelabel-storybook.thedefiengine.tech/?path=/docs/theme-overrides--max-width
     */
    overrides?: Overrides;
}>;
export type { ConfigOptions, ThemeConfig, PinnedTokenProviderProps, Overrides };
//# sourceMappingURL=TheDefiEngineProvider.d.ts.map