var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsxs as _jsxs, jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
import { MaxUint256 } from '@ethersproject/constants';
import { useCallback, useMemo } from 'react';
import { useTokenAllowance } from '../hooks/useTokenAllowance';
import { isEth } from '../utils';
import { useERC20 } from '../hooks/useContract';
import { useActiveWeb3React } from '../hooks/useActiveWeb3React';
import { useMutation } from '@tanstack/react-query';
import { AGGREGATOR_PROXY_ADDRESS } from '../utils/multichain';
import { queryClient } from '../utils/queryClient';
import { Button, CircularProgress } from '@mui/material';
import { TransactionStatus, useUpsertTransaction } from '../providers/TransactionProvider';
import { useOverrides } from '../providers/OverrideProvider';
export var ApprovalState;
(function (ApprovalState) {
    ApprovalState[ApprovalState["UNKNOWN"] = 0] = "UNKNOWN";
    ApprovalState[ApprovalState["NOT_APPROVED"] = 1] = "NOT_APPROVED";
    ApprovalState[ApprovalState["PENDING"] = 2] = "PENDING";
    ApprovalState[ApprovalState["APPROVED"] = 3] = "APPROVED";
})(ApprovalState || (ApprovalState = {}));
// returns a variable indicating the state of the approval and a function which approves if necessary or early returns
export const ApprovalWrapper = ({ amountToApprove, token, children }) => {
    const { account, chainId } = useActiveWeb3React();
    const overrides = useOverrides();
    const upsertTransaction = useUpsertTransaction();
    const spender = AGGREGATOR_PROXY_ADDRESS[chainId];
    const ercContract = useERC20(token === null || token === void 0 ? void 0 : token.address, true);
    const approveMutation = useMutation(() => ercContract.approve(spender, MaxUint256).then((d) => __awaiter(void 0, void 0, void 0, function* () {
        upsertTransaction({
            status: TransactionStatus.Pending,
            txn: d.hash,
            account: account,
            message: `Approve ${token.symbol}`,
            errorMessage: `Failed to approve ${token.symbol}`,
            chainId: chainId,
            createdAt: new Date(),
        });
        yield d.wait();
        return d;
    })), {
        onSuccess: () => {
            queryClient.invalidateQueries(['allowance', token, account, spender]);
        },
        onError: (err) => {
            console.error('Failed to approve token', err);
        },
    });
    const currentAllowance = useTokenAllowance(token, account, spender);
    // check the current approval status
    const approvalState = useMemo(() => {
        if (!amountToApprove || !spender)
            return ApprovalState.UNKNOWN;
        if (isEth(token.address, chainId))
            return ApprovalState.APPROVED;
        // we might not have enough data to know whether or not we need to approve
        if (!currentAllowance)
            return ApprovalState.UNKNOWN;
        // amountToApprove will be defined if currentAllowance is
        return currentAllowance.lt(amountToApprove)
            ? approveMutation.isLoading
                ? ApprovalState.PENDING
                : ApprovalState.NOT_APPROVED
            : ApprovalState.APPROVED;
    }, [amountToApprove, spender, token.address, chainId, currentAllowance, approveMutation.isLoading]);
    const approve = useCallback(() => approveMutation.mutateAsync(), [approveMutation]);
    if (approvalState === ApprovalState.UNKNOWN) {
        return null;
    }
    if (approvalState === ApprovalState.NOT_APPROVED) {
        return (_jsxs(Button, Object.assign({ color: "primary", variant: "contained", fullWidth: true, className: "thedefiengine-approve-button" }, overrides === null || overrides === void 0 ? void 0 : overrides.ApproveButton, { onClick: approve, children: ["Enable ", token.symbol] })));
    }
    if (approvalState === ApprovalState.PENDING) {
        return (_jsx(Button, Object.assign({ color: "primary", variant: "outlined", fullWidth: true, disabled: true, startIcon: _jsx(CircularProgress, { size: "20px" }), className: "thedefiengine-approve-button" }, overrides === null || overrides === void 0 ? void 0 : overrides.ApproveButton, { children: "ENABLING..." })));
    }
    return _jsx(_Fragment, { children: children });
};
//# sourceMappingURL=ApproveWrapper.js.map