var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React, { useMemo, useState } from 'react';
import { Alert, Chip, Fade, InputAdornment, LinearProgress, ListItemButton, Stack, styled, TextField, Typography, } from '@mui/material';
import { useAllowedChains } from '../../hooks/useAllowedChains';
import { useSwitchNetwork } from '../../hooks/useSwitchNetwork';
import { useActiveWeb3React } from '../../hooks/useActiveWeb3React';
import { ChainLogo } from '../Logo/ChainLogo';
import { useDebounceIsNetworkNotMatched } from '../../hooks/useDebounceIsNetworkNotMatched';
import { Search } from '@mui/icons-material';
const StyledWalletButton = styled(ListItemButton)(({ theme }) => ({
    padding: '0.5rem 1rem',
    margin: '0.25rem 0',
    borderRadius: theme.shape.borderRadius,
    maxHeight: '48px',
    backgroundColor: theme.palette.action.hover,
    '&:hover': {
        backgroundColor: theme.palette.action.selected,
    },
}));
export const ConnectionNetworkSelector = React.memo(({ onClose }) => {
    const { chainId, isNotMatched: actualIsNotMatched, walletChainId } = useActiveWeb3React();
    const isNotMatched = useDebounceIsNetworkNotMatched(actualIsNotMatched);
    const { isLoading, canSwitch, switchNetworkAsync } = useSwitchNetwork();
    const chains = useAllowedChains();
    const [search, setSearch] = useState('');
    const filteredChains = useMemo(() => {
        if (!search) {
            return chains;
        }
        const upperSearch = search.toUpperCase();
        return chains.filter((c) => c.id.toString() === upperSearch ||
            c.network.toUpperCase().includes(upperSearch) ||
            c.name.toUpperCase().includes(upperSearch));
    }, [search, chains]);
    return (_jsxs(_Fragment, { children: [_jsx(TextField, { variant: "standard", value: search, onChange: (e) => setSearch(e.target.value), fullWidth: true, placeholder: "Search by network id, name, or symbol", InputProps: {
                    startAdornment: (_jsx(InputAdornment, { position: "start", children: _jsx(Search, {}) })),
                } }), _jsxs(Stack, { maxHeight: "50vh", overflow: "auto", minHeight: "400px", marginRight: -3, paddingRight: 3, py: 0.5, children: [isNotMatched && (_jsx(Alert, { severity: "error", children: "The selected network does not match with the current wallet's network, please switch." })), !canSwitch && _jsx(Alert, { severity: "info", children: "Unable to switch network. Please try it on your wallet." }), _jsx(Fade, { in: isLoading, children: _jsx(LinearProgress, {}) }), filteredChains.map((chain) => {
                        return (_jsx(StyledWalletButton, { disabled: !canSwitch || isLoading || (chainId === chain.id && chain.id === walletChainId), onClick: () => __awaiter(void 0, void 0, void 0, function* () {
                                const isSwitched = yield switchNetworkAsync(chain.id);
                                if (isSwitched) {
                                    onClose();
                                }
                            }), children: _jsxs(Stack, { direction: "row", spacing: 2, alignItems: "center", width: "100%", children: [_jsx(ChainLogo, { size: "32px", chainId: chain.id }), _jsx(Typography, { ml: "0.25rem", fontWeight: "500", flexGrow: "1", children: chain.name }), chainId === chain.id &&
                                        (isNotMatched ? (_jsx(Chip, { label: "Selected", size: "small", color: "error" })) : (_jsx(Chip, { label: "Connected", size: "small", color: "primary" }))), isNotMatched && walletChainId === chain.id && (_jsx(Chip, { size: "small", label: "Wallet Network", color: "primary", variant: "outlined" }))] }) }, chain.id));
                    })] })] }));
});
//# sourceMappingURL=ConnectionNetworkSelector.js.map