var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useEffect, useMemo } from 'react';
import { CircularProgress, ListItemButton, Stack, styled, Typography, DialogContent } from '@mui/material';
import { ModalHeader } from '../ModalHeader';
import { useWallet } from '@solana/wallet-adapter-react';
import { WalletReadyState } from '@solana/wallet-adapter-base';
import { WalletIcon } from './WalletIcon';
import { useAuth } from '../../hooks/useAuth';
const StyledWalletButton = styled(ListItemButton)(({ theme }) => ({
    padding: '1rem',
    margin: '0.5rem 0',
    borderRadius: theme.shape.borderRadius,
    backgroundColor: theme.palette.action.hover,
    '&:hover': {
        backgroundColor: theme.palette.action.selected,
    },
}));
export const WalletConnectSolanaModal = ({ onClose }) => {
    const { wallets, connected } = useWallet();
    const { login, connectingSolanaWallet: connecting } = useAuth();
    useEffect(() => {
        if (connected) {
            onClose();
        }
    }, [connected, onClose]);
    const [walletList] = useMemo(() => {
        const installed = [];
        const notInstalled = [];
        for (const wallet of wallets) {
            if (wallet.readyState === WalletReadyState.Installed) {
                installed.push(wallet);
            }
            else {
                notInstalled.push(wallet);
            }
        }
        const orderedWallets = [...installed, ...notInstalled];
        return [orderedWallets];
    }, [wallets]);
    return (_jsxs(_Fragment, { children: [_jsx(ModalHeader, { title: " Connect Wallet", onClose: onClose }), _jsx(DialogContent, { className: "thedefiengine-connect-wallet-modal-solana", children: connecting || connected ? (_jsxs(Stack, { justifyContent: "center", mt: "2rem", alignItems: "center", textAlign: "center", children: [_jsx(CircularProgress, { size: "90px" }), _jsx("br", {}), _jsx(Typography, { variant: "h6", children: "Waiting to connect" }), _jsx(Typography, { children: "Confirm this connection in your wallet" })] })) : (_jsx(Stack, { children: walletList.map((wallet, i) => {
                        const walletName = wallet.adapter.name === 'Trust' ? 'Trust Wallet' : wallet.adapter.name;
                        return (_jsx(StyledWalletButton, { onClick: () => __awaiter(void 0, void 0, void 0, function* () {
                                login(wallet.adapter.name);
                            }), children: _jsxs(Stack, { direction: "row", spacing: 2, justifyContent: "space-between", alignItems: "center", width: "100%", children: [_jsx(Typography, { fontSize: "large", fontWeight: "500", textTransform: "capitalize", children: walletName }), _jsx(WalletIcon, { wallet: wallet })] }) }, i));
                    }) })) })] }));
};
//# sourceMappingURL=WalletConnectSolanaModal.js.map