import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { SwapEntry } from './SwapEntry';
import { useActiveWeb3React } from '../../hooks/useActiveWeb3React';
import { ConnectionInfoButton } from '../ConnectionInfo/ConnectionInfoButton';
import { useSwapState } from '../../providers/SwapStateProvider';
import { Box, Card, Stack, styled, Typography } from '@mui/material';
import { useTokenList } from '../../hooks/useTokenList';
import { SwapSkeleton } from './SwapSkeleton';
import { SwapConfirmLoading } from './SwapConfirmLoading';
import { TransactionsButton } from '../Transactions/TransactionsButton';
import { useOverrides } from '../../providers/OverrideProvider';
import { useConfig } from '../../providers/ConfigProviders';
import { BuyFiatButton } from '../BuyFiatButton';
import { SWAP_CARD_MAX_WIDTH } from '../../utils/constants';
import CardTitle from '../CardTitle';
import { GasConfigButton } from '../GasConfig/GasConfigButton';
export const SwapCard = React.memo(({ showGasConfigButton = true, showBuyFiatButton = true, showTransactionsButton = true, showConnectionInfoButton = true, title, }) => {
    const { account, isReady } = useActiveWeb3React();
    const [config] = useConfig();
    const [state] = useSwapState();
    const tokenList = useTokenList();
    const isTokenListInited = Boolean(tokenList) && isReady;
    let SwapContent = SwapSkeleton;
    if (isTokenListInited) {
        SwapContent = !state.isConfirming || !account ? SwapEntry : SwapConfirmLoading;
    }
    const overrides = useOverrides();
    const isValidAffiliateFee = React.useMemo(() => {
        const af = Number(config.affiliateFee || 0);
        return af >= 0 && af <= 2;
    }, [config.affiliateFee]);
    const isValidMarketer = React.useMemo(() => {
        var _a;
        const marketer = (_a = config.marketer) !== null && _a !== void 0 ? _a : 'thedefiengine-whitelabel';
        return typeof marketer === 'string' && /^[a-zA-Z-]+$/.test(marketer);
    }, [config.marketer]);
    return (_jsxs(StyledCard, Object.assign({ elevation: 5, className: "thedefiengine-swap-card" }, overrides === null || overrides === void 0 ? void 0 : overrides.Card, overrides === null || overrides === void 0 ? void 0 : overrides.SwapCard, { children: [title !== null && title !== void 0 ? title : (_jsx(CardTitle, { title: "Trade", className: "thedefiengine-swap-title", override: overrides === null || overrides === void 0 ? void 0 : overrides.SwapCardTitle, children: _jsxs(Stack, { direction: "row", spacing: 0, alignItems: "center", children: [showGasConfigButton && !config.hideGasConfigButton && _jsx(GasConfigButton, {}), showBuyFiatButton && !config.hideBuyFiatButton && _jsx(BuyFiatButton, {}), showTransactionsButton && !config.hideTransactionsButton && _jsx(TransactionsButton, {}), showConnectionInfoButton && !config.hideConnectionInfoButton && _jsx(ConnectionInfoButton, {})] }) })), _jsx(Box, { px: 2, pb: 2, mt: 1, children: !isValidAffiliateFee ? (_jsxs(Typography, { color: "error", children: ["Affilicate Fee must be in between ", _jsx("b", { children: "0% - 2%" }), ". Please adjust your config"] })) : !isValidMarketer ? (_jsx(Typography, { color: "error", children: "Invalid Marketer. Please adjust your config" })) : (_jsx(SwapContent, {})) })] })));
});
const StyledCard = styled(Card)(({ theme }) => ({
    maxWidth: SWAP_CARD_MAX_WIDTH,
    minHeight: '400px',
    width: '100%',
    borderRadius: theme.shape.borderRadius,
    boxSizing: 'border-box',
}));
//# sourceMappingURL=SwapCard.js.map