import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React from 'react';
import { useToken } from '../../hooks/useToken';
import { useDerivedAmount } from '../../hooks/useSwapDerivedAmount';
import { SwapDetail } from './SwapDetail';
import { useSwapCallback } from '../../hooks/useSwapCallback';
import { useAggregatorQuote } from '../../hooks/useAggregatorQuote';
import { useWrapOrUnwrap } from '../../hooks/useWrapOrUnwrap';
import { TokenLogo } from '../Logo/TokenLogo';
import { errorMap, ErrorFrom } from '../../utils/errorMap';
import { useActiveWeb3React } from '../../hooks/useActiveWeb3React';
import { useSwapState } from '../../providers/SwapStateProvider';
import { DialogContent, Stack, Typography, Box, Alert, Button, styled, Fade, LinearProgress, Skeleton, } from '@mui/material';
import { ArrowDownward } from '@mui/icons-material';
import { SwapConfirmSkeleton } from './SwapConfirmSkeleton';
import { BASE_SCAN_INFO } from '../../utils/multichain';
import { ScanIcon } from '../Icons';
import { getFormattedCurrencyAmount, truncateHash } from '../../utils';
import { useInputOutputUsdPrice } from '../../hooks/useUSDPrice';
import BigNumber from 'bignumber.js';
import { ModalHeader } from '../ModalHeader';
import { postQuote } from '../../utils/postQuote';
import { useConfig } from '../../providers/ConfigProviders';
import { isSolChain } from '../../utils/chainIdUtil';
import { useAggregatorQuoteParams } from '../../providers/AggregatorQuoteParamsProvider';
import { useGasPriceV2 } from '../../hooks/useGasPriceV2';
export const SwapConfirmModal = React.memo(({ onClose }) => {
    var _a, _b, _c, _d;
    const [state, setState] = useSwapState();
    const handleClose = () => {
        if (state.isConfirming) {
            setState((s) => (Object.assign(Object.assign({}, s), { isConfirming: false, loading: true })));
        }
        onClose();
    };
    const quoteParams = useAggregatorQuoteParams();
    const { account, chainId } = useActiveWeb3React();
    const swapMutation = useSwapCallback();
    const [gasPrice] = useGasPriceV2();
    const [config] = useConfig();
    const affiliateFee = config.affiliateFee;
    const affiliateFeeRecipient = (_b = (_a = config.affiliateFeeRecipientByChains) === null || _a === void 0 ? void 0 : _a[chainId]) !== null && _b !== void 0 ? _b : config.affiliateFeeRecipient;
    const marketer = config.marketer;
    const adjustedQuoteParams = React.useMemo(() => {
        if (!quoteParams)
            return null;
        if (!isSolChain(chainId) && !gasPrice) {
            return null;
        }
        return Object.assign(Object.assign({}, quoteParams), { takerAddress: account, gasPrice: gasPrice });
    }, [quoteParams, chainId, gasPrice, account]);
    // disable quote fetching when swap is in progress or completed
    const { data: quote, error, isFetched, isLoading, } = useAggregatorQuote(adjustedQuoteParams, !swapMutation.isLoading && !swapMutation.isSuccess);
    const inputToken = useToken(state === null || state === void 0 ? void 0 : state.sellTokenAddress);
    const outputToken = useToken(state === null || state === void 0 ? void 0 : state.buyTokenAddress);
    const wrapOrUnWrap = useWrapOrUnwrap(inputToken, outputToken, chainId);
    const [inputAmount, formattedInputAmount] = useDerivedAmount(state.type === 'BUY', state.inputAmount, quote === null || quote === void 0 ? void 0 : quote.sellAmount, inputToken);
    const [outputAmount, formattedOutputAmount] = useDerivedAmount(state.type === 'SELL', state.outputAmount, quote === null || quote === void 0 ? void 0 : quote.buyAmount, outputToken);
    const [inputTokenUsdAmount, outputTokenUsdAmount] = useInputOutputUsdPrice(quote, formattedInputAmount, formattedOutputAmount);
    const canConfirm = Boolean(quote && !swapMutation.isLoading);
    const quoteInfo = Object.assign(Object.assign({ maker: account, sellToken: inputToken.address, buyToken: outputToken.address, dollarValue: inputTokenUsdAmount === null || inputTokenUsdAmount === void 0 ? void 0 : inputTokenUsdAmount.decimalPlaces(3, BigNumber.ROUND_CEIL).toNumber(), chainId: quote === null || quote === void 0 ? void 0 : quote.chainId, createdAt: new Date(), sellTokenValue: formattedInputAmount, buyTokenValue: formattedOutputAmount, from: account, to: quote === null || quote === void 0 ? void 0 : quote.to, value: quote === null || quote === void 0 ? void 0 : quote.value, data: quote === null || quote === void 0 ? void 0 : quote.data, marketer: marketer !== null && marketer !== void 0 ? marketer : 'thedefiengine-whitelabel' }, (affiliateFee !== undefined ? { affiliateFee } : {})), (affiliateFeeRecipient !== undefined ? { affiliateFeeRecipient } : {}));
    const errorMsg = React.useMemo(() => {
        var _a;
        return errorMap((_a = error === null || error === void 0 ? void 0 : error.message) !== null && _a !== void 0 ? _a : '', ErrorFrom.SWAP);
    }, [error]);
    return (_jsxs(_Fragment, { children: [_jsx(Fade, { in: swapMutation.isLoading, children: _jsx(LinearProgress, {}) }), _jsx(ModalHeader, { title: "Confirm Swap", onClose: handleClose }), _jsx(DialogContent, { className: "thedefiengine-confirm-swap", children: swapMutation.isSuccess ? (_jsxs(_Fragment, { children: [_jsx(StyledAlert, { severity: "info", icon: false, children: _jsxs(Stack, { alignItems: "center", width: "100%", spacing: 1, textAlign: "center", children: [_jsx(Typography, { variant: "h5", fontWeight: "bold", children: "Transaction Submitted!" }), _jsx(Typography, { variant: "subtitle2", children: swapMutation.data.message }), _jsxs(Typography, { variant: "subtitle2", children: ["Transaction Hash: ", truncateHash(swapMutation.data.txn, 8, 8)] }), _jsxs(Button, { startIcon: _jsx(ScanIcon, {}), component: "a", href: `${(_c = BASE_SCAN_INFO[swapMutation.data.chainId]) === null || _c === void 0 ? void 0 : _c.url}/tx/${swapMutation.data.txn}`, target: "_blank", children: ["View on ", (_d = BASE_SCAN_INFO[swapMutation.data.chainId]) === null || _d === void 0 ? void 0 : _d.name] })] }) }), _jsx("br", {}), _jsx(Button, { fullWidth: true, variant: "contained", onClick: handleClose, children: "Close" })] })) : errorMsg ? (_jsx(Alert, { severity: "error", children: errorMsg })) : isFetched && !isLoading ? (_jsxs(Stack, { children: [_jsx("br", {}), _jsx(ConfirmTokenInfo, { token: inputToken, tokenFormattedAmount: formattedInputAmount, tokenAmount: inputAmount, tokenUsdPrice: inputTokenUsdAmount, isWrapUnwrap: !!quote.wrapUnwrap }), _jsx(Box, { m: "8px", children: _jsx(ArrowDownward, {}) }), _jsx(ConfirmTokenInfo, { token: outputToken, tokenFormattedAmount: formattedOutputAmount, tokenAmount: outputAmount, tokenUsdPrice: outputTokenUsdAmount, isWrapUnwrap: !!quote.wrapUnwrap }), _jsx("br", {}), !wrapOrUnWrap && (_jsx(SwapDetail, { loading: false, swapType: state.type, amount: state.type === 'SELL' ? inputAmount : outputAmount, quote: quote, inputTokenUSD: inputTokenUsdAmount, outputTokenUSD: outputTokenUsdAmount, inputAmount: formattedInputAmount, outputAmount: formattedOutputAmount })), _jsx("br", {}), _jsx(Button, { variant: "contained", color: "primary", onClick: () => {
                                if (!quote.wrapUnwrap) {
                                    postQuote(quoteInfo);
                                }
                                swapMutation.mutateAsync({
                                    inputToken: inputToken,
                                    outputToken: outputToken,
                                    formattedInputAmount,
                                    formattedOutputAmount,
                                    inputTokenUSD: inputTokenUsdAmount,
                                    quote: quote,
                                }, {
                                    onSuccess: () => {
                                        setState((s) => (Object.assign(Object.assign({}, s), { inputAmount: '', outputAmount: '', isConfirming: false })));
                                    },
                                });
                            }, disabled: !canConfirm, children: swapMutation.isLoading ? 'Confirming...' : 'Confirm' })] })) : (_jsx(SwapConfirmSkeleton, {})) })] }));
});
const StyledAlert = styled(Alert)({
    '& .MuiAlert-message': {
        width: '100%',
    },
});
const ConfirmTokenInfo = ({ token, tokenFormattedAmount, tokenUsdPrice, isWrapUnwrap, }) => {
    var _a;
    //const tokenUsdAmount = useUSDPrice(token)
    return (_jsxs(Stack, { direction: "row", alignItems: "center", spacing: 1, justifyContent: "space-between", children: [_jsxs(Stack, { direction: "row", alignItems: "center", children: [_jsx(TokenLogo, { size: "40px", address: token === null || token === void 0 ? void 0 : token.address }), _jsxs(Stack, { ml: "0.5rem", children: [_jsx(Typography, { variant: "h5", fontWeight: "bold", children: tokenFormattedAmount }), (!isWrapUnwrap || tokenUsdPrice) && (_jsxs(Typography, { variant: "caption", color: "textSecondary", children: ["~", ' ', (_a = getFormattedCurrencyAmount(tokenUsdPrice)) !== null && _a !== void 0 ? _a : _jsx(Skeleton, { width: "25px", sx: { display: 'inline-block' } })] }))] })] }), _jsx(Typography, { fontWeight: "bold", variant: "h5", children: token === null || token === void 0 ? void 0 : token.symbol })] }));
};
//# sourceMappingURL=SwapConfirmModal.js.map