import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { Button, Skeleton, Stack, Tooltip, Typography, styled } from '@mui/material';
import BigNumber from 'bignumber.js';
import React from 'react';
import { useToken } from '../../hooks/useToken';
import { getBalanceAmount, getFormattedAmount } from '../../utils';
import { CallMerge, Help, SwapHoriz, Warning } from '@mui/icons-material';
import { openModal } from '../../providers/ModalContextProvider';
import { ethers } from 'ethers';
import { useConfig } from '../../providers/ConfigProviders';
export const SwapDetail = React.memo(({ swapType, quote, loading, amount, inputTokenUSD, outputTokenUSD, inputAmount, outputAmount }) => {
    var _a, _b, _c, _d;
    const [config] = useConfig();
    const buyToken = useToken(quote === null || quote === void 0 ? void 0 : quote.buyTokenAddress);
    const sellToken = useToken(quote === null || quote === void 0 ? void 0 : quote.sellTokenAddress);
    const token = useToken(swapType === 'BUY' ? quote === null || quote === void 0 ? void 0 : quote.sellTokenAddress : quote === null || quote === void 0 ? void 0 : quote.buyTokenAddress);
    const formattedGuaranteedPrice = React.useMemo(() => {
        if (quote === null || quote === void 0 ? void 0 : quote.guaranteedPriceBigTotal) {
            const bg = new BigNumber(ethers.utils.formatUnits(quote === null || quote === void 0 ? void 0 : quote.guaranteedPriceBigTotal, buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals));
            return bg.gt(0) ? getFormattedAmount(bg) : '-';
        }
        // guaranteed price per token
        if (amount && (quote === null || quote === void 0 ? void 0 : quote.guaranteedPrice)) {
            const bg = new BigNumber(quote === null || quote === void 0 ? void 0 : quote.guaranteedPrice).times(amount);
            return bg.gt(0) ? getFormattedAmount(bg) : '-';
        }
        return '-';
    }, [amount, buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals, quote === null || quote === void 0 ? void 0 : quote.guaranteedPrice, quote === null || quote === void 0 ? void 0 : quote.guaranteedPriceBigTotal]);
    const priceImpact = React.useMemo(() => {
        if (quote === null || quote === void 0 ? void 0 : quote.estimatedPriceImpact) {
            return new BigNumber(quote === null || quote === void 0 ? void 0 : quote.estimatedPriceImpact);
        }
        if (inputAmount && outputAmount && inputTokenUSD && outputTokenUSD) {
            return inputTokenUSD.minus(outputTokenUSD).times(new BigNumber(100)).div(inputTokenUSD);
        }
        return new BigNumber(0);
    }, [inputAmount, outputAmount, inputTokenUSD, outputTokenUSD, quote === null || quote === void 0 ? void 0 : quote.estimatedPriceImpact]);
    const [priceFlip, setPriceFlip] = React.useState(false);
    let tokenA = sellToken;
    let tokenB = buyToken;
    if (priceFlip) {
        tokenA = buyToken;
        tokenB = sellToken;
    }
    const calculatedPriceStr = React.useMemo(() => {
        if (!(quote === null || quote === void 0 ? void 0 : quote.buyAmount) || !(quote === null || quote === void 0 ? void 0 : quote.sellAmount) || !(buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals) || !(sellToken === null || sellToken === void 0 ? void 0 : sellToken.decimals))
            return '';
        const buyAmount = getBalanceAmount(new BigNumber(quote === null || quote === void 0 ? void 0 : quote.buyAmount), buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals);
        const sellAmount = getBalanceAmount(new BigNumber(quote === null || quote === void 0 ? void 0 : quote.sellAmount), sellToken === null || sellToken === void 0 ? void 0 : sellToken.decimals);
        if (priceFlip) {
            return getFormattedAmount(sellAmount.div(buyAmount));
        }
        return getFormattedAmount(buyAmount.div(sellAmount));
    }, [buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals, priceFlip, quote === null || quote === void 0 ? void 0 : quote.buyAmount, quote === null || quote === void 0 ? void 0 : quote.sellAmount, sellToken === null || sellToken === void 0 ? void 0 : sellToken.decimals]);
    if (loading) {
        return (_jsxs(Stack, { minHeight: "40px", children: [_jsxs(Stack, { direction: "row", justifyContent: "space-between", children: [_jsx(Skeleton, { width: "80px" }), _jsx(Skeleton, { width: "50px" })] }), _jsxs(Stack, { direction: "row", justifyContent: "space-between", children: [_jsx(Skeleton, { width: "50px" }), _jsx(Skeleton, { width: "60px" })] }), _jsxs(Stack, { direction: "row", justifyContent: "space-between", children: [_jsx(Skeleton, { width: "60px" }), _jsx(Skeleton, { width: "30px" })] })] }));
    }
    if (!quote)
        return null;
    const numOfSources = (_d = (((_a = quote === null || quote === void 0 ? void 0 : quote.orderRoutes) === null || _a === void 0 ? void 0 : _a.length) || ((_c = (_b = quote === null || quote === void 0 ? void 0 : quote.orderGraph) === null || _b === void 0 ? void 0 : _b.sources) === null || _c === void 0 ? void 0 : _c.length))) !== null && _d !== void 0 ? _d : 0;
    return (_jsxs(Stack, { minHeight: "40px", children: [_jsxs(Stack, { width: "100%", direction: "row", spacing: 1, alignItems: "center", justifyContent: "space-between", children: [_jsxs(Typography, { variant: "caption", color: "textSecondary", children: [swapType === 'SELL' ? 'Minimum Received' : 'Maximum Sold', ' ', _jsx(Tooltip, { title: "Your transaction will revert if there is a large, unfavorable price movement before it is confirmed.", children: _jsx(Help, { className: "thedefiengine-svg", fontSize: "inherit", color: "inherit" }) })] }), _jsxs(Typography, { variant: "caption", color: "textSecondary", children: [formattedGuaranteedPrice, " ", token === null || token === void 0 ? void 0 : token.symbol] })] }), _jsxs(Stack, { width: "100%", direction: "row", spacing: 1, alignItems: "center", justifyContent: "space-between", children: [_jsx(Typography, { variant: "caption", color: "textSecondary", children: "Rate" }), _jsx(StyledButton, { startIcon: _jsx(SwapHoriz, { fontSize: "inherit" }), color: "secondary", onClick: () => setPriceFlip((f) => !f), children: _jsxs(Typography, { variant: "caption", color: "textSecondary", children: ["1 ", tokenA === null || tokenA === void 0 ? void 0 : tokenA.symbol, " = ", calculatedPriceStr, " ", tokenB === null || tokenB === void 0 ? void 0 : tokenB.symbol] }) })] }), _jsxs(Stack, { width: "100%", direction: "row", spacing: 1, alignItems: "center", justifyContent: "space-between", children: [_jsxs(Typography, { variant: "caption", color: "textSecondary", children: ['Price Impact', ' ', _jsx(Tooltip, { title: "When executing a token swap, the price impact refers to the effect the trade has on the market price of the token, typically influenced by factors such as trade size, liquidity, and slippage.", children: _jsx(Help, { className: "thedefiengine-svg", fontSize: "inherit", color: "inherit" }) })] }), _jsx(Typography, { variant: "caption", color: parseFloat(priceImpact.toString()) > 10 ? 'error' : 'textSecondary', children: parseFloat(priceImpact.toString()) > 10 ? (_jsxs(_Fragment, { children: [_jsx(Warning, { className: "thedefiengine-svg", fontSize: "inherit", color: "error" }), " ", priceImpact.toFixed(2), "%"] })) : parseFloat(priceImpact.toString()) > 0.01 ? (` ${priceImpact.toFixed(2)}%`) : ('< 0.01%') })] }), !config.showSwapRouteCard && numOfSources > 0 && (_jsxs(Stack, { width: "100%", direction: "row", spacing: 1, alignItems: "center", justifyContent: "space-between", children: [_jsx(Typography, { variant: "caption", color: "textSecondary", children: "Swap Routing" }), _jsx(StyledButton, { startIcon: _jsx(CallMerge, { fontSize: "inherit" }), color: "secondary", onClick: () => {
                            openModal('swapRoute', { quote });
                        }, children: _jsx(Typography, { variant: "caption", color: "textSecondary", children: numOfSources == 1 ? '1 Source' : numOfSources + ' Sources' }) })] }))] }));
});
const StyledButton = styled(Button)({
    padding: '0 6px',
    marginRight: '-6px !important',
});
//# sourceMappingURL=SwapDetail.js.map