import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { useToken } from '../../hooks/useToken';
import { useAggregatorPrice } from '../../hooks/useAggregatorPrice';
import { useDerivedAmount } from '../../hooks/useSwapDerivedAmount';
import { useBalanceStatus } from '../../hooks/useBalanceStatus';
import { SwapInput } from './SwapInput';
import { SwapDetail } from './SwapDetail';
import { useWrapOrUnwrap } from '../../hooks/useWrapOrUnwrap';
import { useActiveWeb3React } from '../../hooks/useActiveWeb3React';
import { useConfig } from '../../providers/ConfigProviders';
import { getTokenSelectStorageKey, useSwapState } from '../../providers/SwapStateProvider';
import { Alert, Button, Fab, Fade, Stack, styled } from '@mui/material';
import { SwapVert } from '@mui/icons-material';
import { SlippageSetting } from '../SlippageSetting';
import { WalletConnectButton } from '../WalletConnect/WalletConnectButton';
import { closeModal, openModal } from '../../providers/ModalContextProvider';
import { useOverrides } from '../../providers/OverrideProvider';
import { useInputOutputUsdPrice } from '../../hooks/useUSDPrice';
import { DynamicApproveWrapper } from '../DynamicApproveWrapper';
import { getEnableBuyTokenInput } from '../../utils/chainIdUtil';
import { useAggregatorQuoteParams } from '../../providers/AggregatorQuoteParamsProvider';
const StyledFab = styled(Fab)({
    boxShadow: 'none',
    width: '30px',
    height: '30px',
    minHeight: '30px',
    minWidth: '30px',
    zIndex: 1,
});
export const SwapEntry = React.memo(() => {
    const overrides = useOverrides();
    const [state, setState] = useSwapState();
    const quoteParams = useAggregatorQuoteParams();
    const [config] = useConfig();
    const { data: priceQuote, isFetching, isRefetching, error } = useAggregatorPrice(quoteParams);
    const { account, chainId } = useActiveWeb3React();
    const enableBuyTokenInput = getEnableBuyTokenInput(chainId);
    const loading = state.loading || (isFetching && !isRefetching);
    React.useEffect(() => {
        if (state.loading) {
            setState((s) => (Object.assign(Object.assign({}, s), { loading: false })));
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [quoteParams]);
    const inputToken = useToken(state === null || state === void 0 ? void 0 : state.sellTokenAddress);
    const outputToken = useToken(state === null || state === void 0 ? void 0 : state.buyTokenAddress);
    React.useEffect(() => {
        var _a;
        if (inputToken || outputToken)
            (_a = config.onTokenSelect) === null || _a === void 0 ? void 0 : _a.call(config, inputToken, outputToken);
    }, [config, inputToken, outputToken]);
    const wrapOrUnWrap = useWrapOrUnwrap(inputToken, outputToken, chainId);
    const [inputAmount, formattedInputAmount] = useDerivedAmount(state.type === 'BUY', state.inputAmount, priceQuote === null || priceQuote === void 0 ? void 0 : priceQuote.sellAmount, inputToken);
    const [outputAmount, formattedOutputAmount] = useDerivedAmount(state.type === 'SELL', state.outputAmount, priceQuote === null || priceQuote === void 0 ? void 0 : priceQuote.buyAmount, outputToken);
    const [inputTokenUsdAmount, outputTokenUsdAmount] = useInputOutputUsdPrice(priceQuote, formattedInputAmount, formattedOutputAmount);
    const hasInputAmount = inputAmount.gt(0);
    const hasOutputAmount = outputAmount.gt(0);
    const { isEnoughBalance, loaded } = useBalanceStatus(inputToken, inputAmount);
    const canConfirmSwap = Boolean(!loading && isEnoughBalance && inputToken && outputToken && priceQuote);
    const onSelectSellToken = React.useCallback((addr) => {
        setState((s) => {
            var _a;
            const newState = Object.assign(Object.assign({}, s), { sellTokenAddress: addr });
            if (((_a = newState.buyTokenAddress) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === addr.toLowerCase()) {
                // switch if selected token is same as the other token
                newState.buyTokenAddress = s.sellTokenAddress;
                if (!config.disabledPersistSelectedToken)
                    localStorage.setItem(getTokenSelectStorageKey('BUY', chainId), newState.buyTokenAddress || '');
            }
            newState.loading = Boolean(newState.buyTokenAddress && (state.type === 'SELL' ? hasInputAmount : hasOutputAmount));
            if (!config.disabledPersistSelectedToken)
                localStorage.setItem(getTokenSelectStorageKey('SELL', chainId), newState.sellTokenAddress || '');
            return newState;
        });
    }, [chainId, config.disabledPersistSelectedToken, hasInputAmount, hasOutputAmount, setState, state.type]);
    const onSelectBuyToken = React.useCallback((addr) => {
        setState((s) => {
            var _a;
            const newState = Object.assign(Object.assign({}, s), { buyTokenAddress: addr });
            if (((_a = newState.sellTokenAddress) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === addr.toLowerCase()) {
                // switch if selected token is same as the other token
                newState.sellTokenAddress = s.buyTokenAddress;
                if (!config.disabledPersistSelectedToken)
                    localStorage.setItem(getTokenSelectStorageKey('SELL', chainId), newState.sellTokenAddress || '');
            }
            if (!config.disabledPersistSelectedToken)
                localStorage.setItem(getTokenSelectStorageKey('BUY', chainId), newState.buyTokenAddress || '');
            newState.loading = Boolean(newState.sellTokenAddress && (state.type === 'SELL' ? hasInputAmount : hasOutputAmount));
            return newState;
        });
    }, [chainId, config.disabledPersistSelectedToken, hasInputAmount, hasOutputAmount, setState, state.type]);
    const onChangeAmount = React.useCallback((type, amount) => {
        const typeAmount = type === 'SELL' ? 'inputAmount' : 'outputAmount';
        setState((s) => {
            const newState = Object.assign(Object.assign({}, s), { outputAmount: '', inputAmount: '', type: type, loading: Boolean(s.sellTokenAddress && s.buyTokenAddress && Number(amount) > 0), [typeAmount]: amount });
            return newState;
        });
    }, [setState]);
    const onSwitchTokenInput = React.useCallback(() => {
        setState((s) => {
            if (!config.disabledPersistSelectedToken) {
                localStorage.setItem(getTokenSelectStorageKey('BUY', chainId), s.sellTokenAddress || '');
                localStorage.setItem(getTokenSelectStorageKey('SELL', chainId), s.buyTokenAddress || '');
            }
            const newState = Object.assign(Object.assign({}, s), { inputAmount: enableBuyTokenInput ? s.outputAmount : '', outputAmount: enableBuyTokenInput ? s.inputAmount : '', sellTokenAddress: s.buyTokenAddress, buyTokenAddress: s.sellTokenAddress });
            // swap input and output token
            if (s.type === 'SELL') {
                return Object.assign(Object.assign({}, newState), { type: 'BUY', loading: Boolean(s.buyTokenAddress && s.sellTokenAddress && s.inputAmount) });
            }
            return Object.assign(Object.assign({}, newState), { type: 'SELL', loading: Boolean(s.buyTokenAddress && s.sellTokenAddress && s.outputAmount) });
        });
    }, [setState, config.disabledPersistSelectedToken, enableBuyTokenInput, chainId]);
    return (_jsx(Fade, { in: true, children: _jsxs("div", { children: [_jsx(SwapInput, { type: "SELL", isActivate: 'SELL' === state.type, token: inputToken, loading: state.type === 'BUY' && loading, onChangeToken: onSelectSellToken, amount: formattedInputAmount, onChangeAmount: onChangeAmount, tokenUsdPrice: inputTokenUsdAmount }), _jsx(Stack, { alignItems: "center", height: "20px", marginTop: "-10px", children: _jsx(StyledFab, Object.assign({ onClick: onSwitchTokenInput, className: "thedefiengine-switch-swap-button", size: "small", color: "primary" }, overrides === null || overrides === void 0 ? void 0 : overrides.SwitchSwapButton, { children: _jsx(SwapVert, {}) })) }), _jsx(SwapInput, { disabled: !enableBuyTokenInput, type: "BUY", isActivate: 'BUY' === state.type, loading: state.type === 'SELL' && loading, token: outputToken, onChangeToken: onSelectBuyToken, amount: formattedOutputAmount, onChangeAmount: onChangeAmount, tokenUsdPrice: outputTokenUsdAmount }), _jsxs(Stack, { spacing: 2, mt: "1rem", children: [_jsx(SlippageSetting, {}), error && _jsx(Alert, { severity: "error", children: error.message }), account &&
                            inputToken &&
                            (!loaded ? (_jsx(Button, Object.assign({ variant: "contained", color: "primary", fullWidth: true, disabled: true, className: "thedefiengine-confirm-swap-button" }, overrides === null || overrides === void 0 ? void 0 : overrides.ConfirmSwapButton, { children: "Loading Wallet Balance..." }))) : (!isEnoughBalance && (_jsxs(Button, Object.assign({ variant: "contained", color: "primary", fullWidth: true, disabled: true, className: "thedefiengine-confirm-swap-button" }, overrides === null || overrides === void 0 ? void 0 : overrides.ConfirmSwapButton, { children: ["Insufficient ", inputToken === null || inputToken === void 0 ? void 0 : inputToken.symbol, " balance"] }))))), isEnoughBalance && (_jsx(DynamicApproveWrapper, { amountToApprove: inputAmount, token: inputToken, children: _jsx(Button, Object.assign({ disabled: !canConfirmSwap, variant: "contained", fullWidth: true, color: "primary", className: "thedefiengine-confirm-swap-button" }, overrides === null || overrides === void 0 ? void 0 : overrides.ConfirmSwapButton, { onClick: () => {
                                    openModal('confirmSwap', undefined, {
                                        onClose: () => {
                                            setState((s) => (Object.assign(Object.assign({}, s), { isConfirming: false, loading: s.isConfirming })));
                                            closeModal('confirmSwap');
                                        },
                                    });
                                    setState((s) => (Object.assign(Object.assign({}, s), { isConfirming: true })));
                                }, children: _jsx("b", { children: wrapOrUnWrap || 'Confirm Swap' }) })) })), !account && _jsx(WalletConnectButton, { fullWidth: true, size: "large" }), !wrapOrUnWrap && (_jsx(SwapDetail, { loading: loading, swapType: state.type, amount: state.type === 'SELL' ? inputAmount : outputAmount, quote: priceQuote, inputTokenUSD: inputTokenUsdAmount, outputTokenUSD: outputTokenUsdAmount, inputAmount: formattedInputAmount, outputAmount: formattedOutputAmount }))] })] }) }));
});
//# sourceMappingURL=SwapEntry.js.map