import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ContentCopy } from '@mui/icons-material';
import { Box, Button, IconButton, Skeleton, Stack, styled, Tooltip, Typography } from '@mui/material';
import React, { useMemo } from 'react';
import { useWalletBalance } from '../../hooks/useWalletBalance';
import { getFormattedCurrencyAmount, isEth } from '../../utils';
import { BASE_SCAN_INFO, ETH } from '../../utils/multichain';
import { ScanIcon } from '../Icons';
import { TokenPinnerButton } from '../TokenPinner/TokenPinnerButton';
import { TokenSelectorButton } from '../TokenSelector/TokenSelectorButton';
import { getFormattedAmount } from '../../utils/index';
import { NumericFormat } from 'react-number-format';
import { useOverrides } from '../../providers/OverrideProvider';
import copyToClipboard from 'copy-to-clipboard';
import { useActiveWeb3React } from '../../hooks/useActiveWeb3React';
const StyledMaxButton = styled(Button)(({ theme }) => ({
    minWidth: 'auto',
    fontSize: '0.65rem',
    padding: '0 4px',
    marginLeft: 4,
    fontWeight: 'bold',
}));
const minEth = 0.01;
export const SwapInput = React.memo(({ type, amount = '', tokenUsdPrice, token, isActivate, onChangeToken, onChangeAmount, loading, disabled = false, }) => {
    var _a, _b;
    const overrides = useOverrides();
    const tokenBalance = useWalletBalance(token);
    const { chainId } = useActiveWeb3React();
    const selectableMaxAmount = useMemo(() => {
        if (tokenBalance === null || tokenBalance === void 0 ? void 0 : tokenBalance.gt(0)) {
            if (isEth(token === null || token === void 0 ? void 0 : token.address, chainId)) {
                const newBalance = tokenBalance.minus(minEth);
                if (newBalance.gt(0)) {
                    return newBalance.toString();
                }
            }
            return tokenBalance.toString();
        }
        return undefined;
    }, [tokenBalance, token === null || token === void 0 ? void 0 : token.address, chainId]);
    const handleSetMax = () => {
        if (selectableMaxAmount !== amount) {
            onChangeAmount(type, selectableMaxAmount);
        }
    };
    return (_jsxs(StyledInputContainer, Object.assign({ className: "thedefiengine-swap-input-container" }, overrides === null || overrides === void 0 ? void 0 : overrides.SwapInputContainer, { children: [_jsxs(StyledInputBox, { children: [_jsx("div", { children: _jsx(TokenSelectorButton, { size: "small", selectedTokenAddress: token === null || token === void 0 ? void 0 : token.address, onSelect: onChangeToken }) }), loading ? (_jsx(StyledInputSkeleton, {})) : (_jsx(NumericFormat, Object.assign({ disabled: disabled, placeholder: "0", className: "thedefiengine-swap-input", inputMode: "decimal", allowedDecimalSeparators: ['.', ','], valueIsNumericString: true, allowNegative: false, allowLeadingZeros: false, onValueChange: ({ value }) => onChangeAmount(type, value), value: amount, customInput: StyledInput }, overrides === null || overrides === void 0 ? void 0 : overrides.SwapInput)))] }), _jsxs(Stack, { height: "26px", direction: "row", alignItems: "center", justifyContent: "space-between", children: [_jsxs(StyledActions, { children: [_jsxs(StyledTypography, { fontWeight: isActivate ? 'bold' : 'inherit', textTransform: "capitalize", variant: "caption", color: "textSecondary", lineHeight: 0, children: ["You ", type.toLowerCase()] }), ' ', token && (_jsxs(_Fragment, { children: [_jsx(Tooltip, { title: `Pin ${token.symbol}`, children: _jsx("span", { children: _jsx(TokenPinnerButton, { address: token === null || token === void 0 ? void 0 : token.address, color: "inherit" }) }) }), token.address !== ETH[chainId].address && (_jsxs(_Fragment, { children: [_jsx(Tooltip, { title: `Copy ${token.symbol} address`, children: _jsx(IconButton, { color: "inherit", size: "small", onClick: () => {
                                                        try {
                                                            copyToClipboard(token.address);
                                                        }
                                                        catch (ex) {
                                                            console.error(ex);
                                                        }
                                                    }, children: _jsx(ContentCopy, { fontSize: "inherit", color: "inherit" }) }) }), _jsx(Tooltip, { title: `View on ${(_a = BASE_SCAN_INFO[token.chainId]) === null || _a === void 0 ? void 0 : _a.name}`, children: _jsx(IconButton, { size: "small", component: "a", color: "inherit", href: `${(_b = BASE_SCAN_INFO[token.chainId]) === null || _b === void 0 ? void 0 : _b.url}/address/${token.address}`, target: "_blank", children: _jsx(ScanIcon, { fontSize: "inherit", color: "inherit" }) }) })] }))] }))] }), tokenBalance && (_jsxs(Stack, { direction: "row", alignItems: "center", justifyContent: "flex-end", children: [_jsxs(StyledTypography, { variant: "caption", color: "textSecondary", lineHeight: 0, children: ["Balance: ", getFormattedAmount(tokenBalance, 6, true)] }), selectableMaxAmount && type === 'SELL' && (_jsx(StyledMaxButton, { onClick: handleSetMax, color: "primary", variant: "outlined", size: "small", children: "Max" }))] }))] }), _jsx(Box, { height: 40 }), _jsxs(Stack, { height: "26px", direction: "row", alignItems: "center", justifyContent: "space-between", children: [_jsx(StyledTypography, { variant: "caption", color: "textSecondary", lineHeight: 0, children: token === null || token === void 0 ? void 0 : token.name }), !loading && amount && tokenUsdPrice && (_jsxs(StyledTypography, { variant: "caption", color: "textSecondary", lineHeight: 0, children: ["~ ", getFormattedCurrencyAmount(tokenUsdPrice)] }))] })] })));
});
const StyledInputSkeleton = styled(Skeleton)(({ theme }) => ({
    zIndex: 1,
    width: 100,
    lineHeight: 'auto',
    height: 40,
    marginRight: `${theme.spacing(1.5)} !important`,
}));
const StyledTypography = styled(Typography)({
    zIndex: 1,
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap',
});
const StyledActions = styled('div')(({ theme }) => ({
    display: 'flex',
    flexDirection: 'row',
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    alignItems: 'center',
    '& button': {
        fontSize: '1rem',
    },
    color: theme.palette.text.secondary,
}));
const StyledInputBox = styled('div')(({ theme }) => ({
    boxSizing: 'border-box',
    padding: `0px !important`,
    paddingLeft: `${theme.spacing(1.5)} !important`,
    borderRadius: `${theme.shape.borderRadius}px !important`,
    top: 0,
    left: 0,
    position: 'absolute',
    width: `100%`,
    height: '100%',
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
}));
const StyledInput = styled('input')(({ theme }) => ({
    outline: 'none',
    border: 'none !important',
    textAlign: 'right',
    fontSize: '1.75rem',
    paddingRight: `${theme.spacing(1.5)} !important`,
    [theme.breakpoints.down(350)]: {
        fontSize: '1.5rem',
    },
    borderRadius: `${theme.shape.borderRadius}px !important`,
    color: theme.palette.text.primary,
    boxSizing: 'border-box',
    width: `100%`,
    height: '100%',
    background: 'transparent',
    appearance: 'none',
}));
const StyledInputContainer = styled(Box)(({ theme }) => ({
    borderRadius: theme.shape.borderRadius,
    border: `1px solid ${theme.palette.divider}`,
    padding: `10px ${theme.spacing(1.5)}`,
    position: 'relative',
    '&:focus-within': {
        borderColor: theme.palette.primary.main,
    },
    transition: 'border 0.3s ease',
    minHeight: 92,
}));
//# sourceMappingURL=SwapInput.js.map