import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useMemo } from 'react';
import { useToken } from '../../hooks/useToken';
import { TokenLogo } from '../Logo/TokenLogo';
import { Stack, Typography, styled, useTheme, Box } from '@mui/material';
import { ArrowForward } from '@mui/icons-material';
import { getBalanceAmount, getFormattedAmount } from '../../utils';
import BigNumber from 'bignumber.js';
import Xarrow, { Xwrapper } from 'react-xarrows';
const StyledText = styled('span')({
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    width: '100%',
    display: 'block',
});
const textFontSize = { xs: '12px', sm: '16px' };
const textFontSizeSmall = { xs: '8px', sm: '12px' };
const dashness = {
    animation: 1,
};
const CustomArrow = (props) => {
    const theme = useTheme();
    return _jsx(Xarrow, Object.assign({ headSize: 6, strokeWidth: 2, color: theme.palette.primary.main, dashness: dashness }, props));
};
const TokenWrapper = ({ addr }) => {
    const token = useToken(addr);
    return (_jsxs(Stack, { alignItems: "center", justifyContent: "center", p: "5px", direction: { xs: 'column', md: 'row' }, children: [_jsx(TokenLogo, { address: addr }), _jsx(Typography, { fontWeight: "bold", mx: "5px", fontSize: textFontSize, children: token === null || token === void 0 ? void 0 : token.symbol })] }));
};
const IndividualRoute = ({ edge, graph }) => {
    // calculate all the path to the end from the graph
    const PathDetail = useMemo(() => {
        const queue = [edge];
        const visited = new Set();
        const rows = [];
        while (queue.length > 0) {
            let leftover = queue.length;
            const cols = [];
            while (leftover > 0) {
                leftover--;
                const node = queue.shift();
                if (visited.has(node.targetAddress)) {
                    continue;
                }
                visited.add(node.targetAddress);
                for (const key in graph.nodes[node.targetAddress]) {
                    queue.push(graph.nodes[node.targetAddress][key]);
                }
                cols.push(_jsxs(Stack, { direction: "row", children: [rows.length > 0 && (_jsx(Stack, { alignItems: "center", mt: 1, spacing: 1, children: _jsx(ArrowForward, { fontSize: "small", color: "primary" }) })), _jsxs(Stack, { alignItems: "center", children: [_jsx(TokenWrapper, { addr: node.targetAddress }), _jsx("div", { children: node.sources.map((source, i) => (_jsxs(Typography, { color: "textSecondary", fontSize: textFontSizeSmall, children: [source.label, " ", node.sources.length > 1 && rows.length === 0 && `- ${source.percent}%`] }, i))) })] })] }, node.targetAddress));
            }
            rows.push(_jsx(Stack, { direction: "row", children: cols }, rows.length));
        }
        return rows;
    }, [edge, graph.nodes]);
    return (_jsxs(Stack, { justifyContent: "center", mb: "1em", children: [_jsx("div", { id: edge.targetAddress, children: _jsxs(Box, { component: "fieldset", sx: {
                        borderRadius: 1,
                        border: '1px solid gray',
                        minWidth: { xs: '150px', md: '310px' },
                    }, children: [_jsx(Typography, { component: "legend", display: "flex", alignItems: "center", fontWeight: "bold", px: 1, color: "primary", children: _jsxs(Typography, { display: "inline-block", fontSize: "16px", fontWeight: "bold", children: [edge.percent, "%"] }) }), _jsx(Stack, { direction: "row", children: PathDetail })] }) }), _jsx(CustomArrow, { startAnchor: "bottom", endAnchor: "left", start: "router-start", end: edge.targetAddress }), _jsx(CustomArrow, { startAnchor: "right", endAnchor: "bottom", start: edge.targetAddress, end: "router-end" })] }));
};
export const SwapRouteByToken = React.memo(({ quote }) => {
    const sellToken = useToken(quote.sellTokenAddress);
    const buyToken = useToken(quote.buyTokenAddress);
    const [buyAmount, sellAmount] = React.useMemo(() => [
        getFormattedAmount(getBalanceAmount(new BigNumber(quote === null || quote === void 0 ? void 0 : quote.buyAmount), buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals)),
        getFormattedAmount(getBalanceAmount(new BigNumber(quote === null || quote === void 0 ? void 0 : quote.sellAmount), sellToken === null || sellToken === void 0 ? void 0 : sellToken.decimals)),
    ], [buyToken === null || buyToken === void 0 ? void 0 : buyToken.decimals, quote === null || quote === void 0 ? void 0 : quote.buyAmount, quote === null || quote === void 0 ? void 0 : quote.sellAmount, sellToken === null || sellToken === void 0 ? void 0 : sellToken.decimals]);
    if (!quote.orderGraph) {
        return;
    }
    return (_jsxs(Xwrapper, { children: [_jsxs(Stack, { width: "100%", direction: "row", justifyContent: "space-between", spacing: 1, children: [_jsxs(Stack, { alignItems: { xs: 'flex-start', sm: 'center' }, direction: { xs: 'column-reverse', sm: 'row' }, children: [_jsx("div", { id: "router-start", children: _jsx(TokenLogo, { address: quote.sellTokenAddress }) }), _jsxs(Typography, { fontSize: textFontSize, fontWeight: "bold", ml: "0.5em", children: [_jsx(StyledText, { children: sellAmount }), " ", sellToken === null || sellToken === void 0 ? void 0 : sellToken.symbol] })] }), _jsxs(Stack, { alignItems: { xs: 'flex-end', sm: 'center' }, direction: { xs: 'column', sm: 'row' }, children: [_jsxs(Typography, { fontSize: textFontSize, fontWeight: "bold", mr: "0.5em", textAlign: "right", children: [_jsx(StyledText, { children: buyAmount }), " ", buyToken === null || buyToken === void 0 ? void 0 : buyToken.symbol] }), _jsx("div", { id: "router-end", children: _jsx(TokenLogo, { address: quote.buyTokenAddress }) })] })] }), _jsx("br", {}), _jsx(Stack, { px: "24px", alignItems: "center", children: Object.values(quote.orderGraph.nodes[quote.sellTokenAddress]).map((edge, i) => (_jsx(IndividualRoute, { edge: edge, graph: quote.orderGraph }, i))) })] }));
});
//# sourceMappingURL=SwapRouteByToken.js.map