import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState } from 'react';
import { Button, Collapse, DialogContent, Link, Stack, Typography } from '@mui/material';
import { KeyboardArrowDown, KeyboardArrowUp } from '@mui/icons-material';
import { parseGoPlusResult, parseGoPlusResultOther } from '../../utils/goPlusUtils';
import { ModalHeader } from '../ModalHeader';
import { GoPlusImageSrc } from '../../utils/constants';
var GoPlusDescription;
(function (GoPlusDescription) {
    GoPlusDescription["is_mintable"] = "Whether this contract has the function to mint new tokens.";
    GoPlusDescription["is_open_source"] = "Whether the contract for this token is open source. Contracts that aren't open source may hide various unknown mechanisms and an increase risks significantly.";
    GoPlusDescription["is_proxy"] = "Whether this token uses a proxy contract. Most proxy contracts are accompanied by modifiable implementation contracts, which may contain significant potential risk";
    GoPlusDescription["owner_address"] = "";
    GoPlusDescription["can_take_back_ownership"] = "";
    GoPlusDescription["owner_change_balance"] = "Whether the contract owner can change token holder balances";
    GoPlusDescription["hidden_owner"] = "Whether the contract has hidden owners. Hidden ownership is used by developers to maintain ownership ability even after abandoning ownership, and is often an indicator of malicious intent.";
    GoPlusDescription["selfdestruct"] = "";
    GoPlusDescription["external_call"] = "";
    GoPlusDescription["gas_abuse"] = "";
    GoPlusDescription["is_in_dex"] = "";
    GoPlusDescription["cannot_buy"] = "Whether the contract has the function to restrict token holders from buying the token";
    GoPlusDescription["cannot_sell_all"] = "Whether the contract has the function to restrict token holders from selling their entire position";
    GoPlusDescription["slippage_modifiable"] = "Whether buy/sell tax can be modified in the token contract";
    GoPlusDescription["is_honeypot"] = "Whether the token is a honeypot, a token that can't be sold due to malicious code on its contract";
    GoPlusDescription["transfer_pausable"] = "Whether trading can be paused by the token contract";
    GoPlusDescription["is_blacklisted"] = "Whether the blacklist function is included in the contract. If there is a blacklist, some addresses may not be able to trade this token";
    GoPlusDescription["is_whitelisted"] = "Whether the whitelist function is included in the contract. Whitelisting is mostly used to allow specific addresses to make early transactions, tax-free, and not affected by transaction suspension";
    GoPlusDescription["is_anti_whale"] = "Whether the contract has the function to limit the maximum amount of transactions or the maximum token position for a single address";
    GoPlusDescription["anti_whale_modifiable"] = "Whether the contract has the function to modify the maximum amount of transactions or the maximum token position.";
    GoPlusDescription["trading_cooldown"] = "Whether the contract has a trading-cool-down mechanism that can limit the minimum time between two transactions.";
    GoPlusDescription["personal_slippage_modifiable"] = "Whether the owner can set a different tax rate for every assigned address.";
    GoPlusDescription["is_true_token"] = "It describes whether the token is true or fake.";
    GoPlusDescription["is_airdrop_scam"] = "It describes whether the token is an airdrop scam.";
    GoPlusDescription["trust_list"] = "It describes whether the token is a famous and trustworthy one.";
})(GoPlusDescription || (GoPlusDescription = {}));
const GoPlusModal = ({ onClose, goPlusInfo }) => {
    return (_jsxs(_Fragment, { children: [_jsx(ModalHeader, { onClose: onClose, title: _jsx(Link, { href: 'https://gopluslabs.io/', target: "_blank", mb: "5px", children: _jsx("img", { src: GoPlusImageSrc, height: 20, alt: "GoPlus" }) }) }), _jsx(DialogContent, { children: _jsxs(Stack, { spacing: 1, children: [_jsxs(Typography, { variant: "body2", children: ["GoPlus is working as the ", '"Security Infrastructure"', " for Web3 by providing open, permissionless, user-driven Security Services. It is building on the Security Data Infrastructure and Security Service Platform, making a safer Web3 Ecosystem."] }), _jsx(CollapsibleText, { title: "Modifiable Tax", secondaryText: parseGoPlusResult(goPlusInfo.slippage_modifiable), collapsedText: GoPlusDescription.slippage_modifiable }), _jsx(CollapsibleText, { title: "Blacklist", secondaryText: parseGoPlusResult(goPlusInfo.is_blacklisted), collapsedText: GoPlusDescription.is_blacklisted }), _jsx(CollapsibleText, { title: "Whitelist", secondaryText: parseGoPlusResult(goPlusInfo.is_whitelisted), collapsedText: GoPlusDescription.is_whitelisted }), _jsx(CollapsibleText, { title: "Hidden Owner", secondaryText: parseGoPlusResult(goPlusInfo.hidden_owner), collapsedText: GoPlusDescription.hidden_owner }), _jsx(CollapsibleText, { title: "Open Source", secondaryText: parseGoPlusResultOther(goPlusInfo.is_open_source), collapsedText: GoPlusDescription.is_open_source }), _jsx(CollapsibleText, { title: "Honeypot", secondaryText: parseGoPlusResult(goPlusInfo.is_honeypot), collapsedText: GoPlusDescription.is_honeypot }), _jsx(CollapsibleText, { title: "Proxy Contract", secondaryText: parseGoPlusResult(goPlusInfo.is_proxy), collapsedText: GoPlusDescription.is_proxy }), _jsx(CollapsibleText, { title: "Mint Function", secondaryText: parseGoPlusResult(goPlusInfo.is_mintable), collapsedText: GoPlusDescription.is_mintable }), _jsx(CollapsibleText, { title: "Transfer Pausable", secondaryText: parseGoPlusResult(goPlusInfo.transfer_pausable), collapsedText: GoPlusDescription.transfer_pausable }), _jsx(CollapsibleText, { title: "Trading Cooldown", secondaryText: parseGoPlusResult(goPlusInfo.trading_cooldown), collapsedText: GoPlusDescription.trading_cooldown }), _jsx(CollapsibleText, { title: "Cannot Sell All", secondaryText: parseGoPlusResult(goPlusInfo.cannot_sell_all), collapsedText: GoPlusDescription.cannot_sell_all }), _jsx(CollapsibleText, { title: "Cannot Be Bought", secondaryText: parseGoPlusResult(goPlusInfo.cannot_buy), collapsedText: GoPlusDescription.cannot_buy }), _jsx(CollapsibleText, { title: "Owner Can Change Balance", secondaryText: parseGoPlusResult(goPlusInfo.owner_change_balance), collapsedText: GoPlusDescription.owner_change_balance }), _jsx(CollapsibleText, { title: "Anti Whale", secondaryText: parseGoPlusResult(goPlusInfo.is_anti_whale), collapsedText: GoPlusDescription.is_anti_whale }), _jsx(CollapsibleText, { title: "Modifiable Anti Whale", secondaryText: parseGoPlusResult(goPlusInfo.anti_whale_modifiable), collapsedText: GoPlusDescription.anti_whale_modifiable }), _jsx(CollapsibleText, { title: "Modifiable Anti Whale", secondaryText: parseGoPlusResult(goPlusInfo.anti_whale_modifiable), collapsedText: GoPlusDescription.anti_whale_modifiable }), _jsx(CollapsibleText, { title: "Address Specific Modifiable Tax", secondaryText: parseGoPlusResult(goPlusInfo.personal_slippage_modifiable), collapsedText: GoPlusDescription.personal_slippage_modifiable })] }) })] }));
};
const CollapsibleText = ({ title, secondaryText, collapsedText, }) => {
    const [open, setOpen] = useState(false);
    return (_jsxs(_Fragment, { children: [_jsx(Button, { onClick: () => {
                    setOpen(!open);
                }, children: _jsxs(Stack, { width: "100%", direction: "row", spacing: 2, justifyContent: "flex-start", children: [_jsx(Typography, { fontWeight: "bold", align: "left", color: "textPrimary", variant: "subtitle1", flexGrow: "1", children: title }), _jsx(Typography, { color: "textPrimary", variant: "subtitle1", children: secondaryText }), open ? _jsx(KeyboardArrowUp, { color: "action" }) : _jsx(KeyboardArrowDown, { color: "action" })] }) }), _jsx(Collapse, { in: open, timeout: "auto", children: _jsx(Typography, { px: 1, variant: "body2", children: collapsedText }) })] }));
};
export default GoPlusModal;
//# sourceMappingURL=GoPlusModal.js.map