import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useMemo } from 'react';
import useTokenGoPlus from '../../hooks/useTokenGoPlus';
import { Alert, Box, Button, Chip, Grid, IconButton, Link, Stack, Tooltip, Typography } from '@mui/material';
import { TokenLogo } from '../Logo/TokenLogo';
import { useUSDPrice } from '../../hooks/useUSDPrice';
import { formatNumberWithAbbrev, getFormattedAmount, truncateHash } from '../../utils';
import copyToClipboard from 'copy-to-clipboard';
import { ContentCopy, Language, Telegram, X, YouTube } from '@mui/icons-material';
import { BASE_SCAN_INFO, CHART_LINK } from '../../utils/multichain';
import { DiscordIcon, ScanIcon } from '../Icons';
import { getGoPlusScoring } from '../../utils/goPlusUtils';
import { openModal } from '../../providers/ModalContextProvider';
import { GoPlusImageSrc } from '../../utils/constants';
import { isSolChain } from '../../utils/chainIdUtil';
import useSolMarketData from '../../hooks/useSolMarketData';
import { useWrappedAddress } from '../../hooks/useWrappedAddress';
import CandlestickChartIcon from '@mui/icons-material/CandlestickChart';
import { TokenSparkLine } from './TokenSparkLine';
import useMarketChartData from '../../hooks/useMarketChartData';
import BigNumber from 'bignumber.js';
const PET = '0xc2132D05D31c914a87C6611C10748AEb04B58e8F';
const DEFAULT_INFO_LIST = [
    {
        label: 'Holders',
        value: '',
    },
    {
        label: 'Liquidity',
        value: '',
    },
    {
        label: 'Market Cap',
        value: '',
    },
    {
        label: 'Total Supply',
        value: '',
    },
];
export const TokenInfo = React.memo(({ token, otherToken }) => {
    var _a, _b, _c, _d;
    const goPlusInfo = useTokenGoPlus(token);
    const { name, symbol, address, socialLinks, shortDescription, website } = token;
    const isSol = isSolChain(token.chainId);
    const solMarkData = useSolMarketData(token);
    const marketChartData = useMarketChartData(token);
    const priceFromMarketChartData = (_b = (_a = marketChartData === null || marketChartData === void 0 ? void 0 : marketChartData.prices) === null || _a === void 0 ? void 0 : _a.at(-1)) === null || _b === void 0 ? void 0 : _b[1];
    const fetchedPrice = useUSDPrice(token);
    const price = useMemo(() => {
        if (fetchedPrice) {
            return fetchedPrice;
        }
        if (priceFromMarketChartData) {
            return new BigNumber(priceFromMarketChartData);
        }
        return null;
    }, [priceFromMarketChartData, fetchedPrice]);
    const otherPrice = useUSDPrice(otherToken);
    const priceOther = React.useMemo(() => {
        if ((price === null || price === void 0 ? void 0 : price.gt(0)) && (otherPrice === null || otherPrice === void 0 ? void 0 : otherPrice.gt(0))) {
            return price.div(otherPrice);
        }
        return null;
    }, [price, otherPrice]);
    const transformedName = name;
    const shortDescriptionMod = shortDescription;
    const solInfoList = useMemo(() => {
        if (!solMarkData) {
            return DEFAULT_INFO_LIST;
        }
        return [
            {
                label: 'Holders',
                value: '-',
            },
            {
                label: 'Liquidity',
                value: '-',
            },
            {
                label: 'Market Cap',
                value: formatNumberWithAbbrev(Number(price) * solMarkData.totalSupply, 2, '$'),
            },
            {
                label: 'Total Supply',
                value: formatNumberWithAbbrev(solMarkData.totalSupply, 2),
            },
        ];
    }, [solMarkData, price]);
    const { taxDisplayValue, infoList } = useMemo(() => {
        var _a, _b;
        if (!goPlusInfo) {
            return {
                taxDisplayValue: '',
                infoList: DEFAULT_INFO_LIST,
            };
        }
        const liquidityTotal = (_b = (_a = goPlusInfo === null || goPlusInfo === void 0 ? void 0 : goPlusInfo.dex) === null || _a === void 0 ? void 0 : _a.reduce((total, item) => total + parseInt(item.liquidity, 10), 0)) !== null && _b !== void 0 ? _b : 0;
        return {
            taxDisplayValue: `${(Number(goPlusInfo.buy_tax) * 100).toFixed(0)} / ${(Number(goPlusInfo.sell_tax) * 100).toFixed(0)}`,
            infoList: [
                {
                    label: 'Holders',
                    value: formatNumberWithAbbrev(Number(goPlusInfo.holder_count), Number(goPlusInfo.holder_count) < 1000 ? 0 : 2),
                },
                {
                    label: 'Liquidity',
                    value: formatNumberWithAbbrev(2 * liquidityTotal, 2, '$'),
                },
                {
                    label: 'Market Cap',
                    value: formatNumberWithAbbrev(Number(price) * Number(goPlusInfo.total_supply), 2, '$'),
                },
                {
                    label: 'Total Supply',
                    value: formatNumberWithAbbrev(Number(goPlusInfo.total_supply), 2),
                },
            ],
        };
    }, [goPlusInfo, price]);
    const goPlusScore = useMemo(() => {
        if (!goPlusInfo) {
            return '';
        }
        return getGoPlusScoring(goPlusInfo);
    }, [goPlusInfo]);
    return (_jsxs(Stack, { spacing: 1, height: "100%", children: [_jsxs(Stack, { direction: "row", alignItems: "center", justifyContent: "space-between", spacing: 2, children: [_jsxs(Stack, { direction: "row", alignItems: "center", spacing: 2, children: [_jsx(TokenLogo, { address: address, width: "40px", height: "40px" }), _jsxs("div", { children: [_jsx(Typography, { fontWeight: "bold", variant: "h6", color: "primary", children: transformedName }), _jsx(Typography, { fontWeight: "bold", children: symbol })] })] }), _jsxs("div", { children: [(price === null || price === void 0 ? void 0 : price.gt(0)) && (_jsxs(Typography, { fontWeight: "bold", variant: "h6", align: "right", children: ["$", getFormattedAmount(price, 4)] })), priceOther && (_jsxs(Typography, { color: "textSecondary", align: "right", children: [getFormattedAmount(priceOther, 4), " ", otherToken.symbol] }))] })] }), _jsxs(Stack, { direction: "row", alignItems: "center", spacing: 1, py: 1, children: [_jsxs("div", { children: [_jsxs(Stack, { direction: "row", alignItems: "center", children: [_jsx(Tooltip, { title: token.address, children: _jsx(Typography, { variant: "subtitle2", fontWeight: "bold", children: truncateHash(token.address, 2, 4) }) }), _jsx(Tooltip, { title: `Copy ${token.symbol} address`, children: _jsx(IconButton, { size: "small", onClick: () => {
                                                try {
                                                    copyToClipboard(token.address);
                                                }
                                                catch (ex) {
                                                    console.error(ex);
                                                }
                                            }, children: _jsx(ContentCopy, { fontSize: "inherit" }) }) }), _jsx(Tooltip, { title: `View on ${(_c = BASE_SCAN_INFO[token.chainId]) === null || _c === void 0 ? void 0 : _c.name}`, children: _jsx(IconButton, { size: "small", component: "a", href: `${(_d = BASE_SCAN_INFO[token.chainId]) === null || _d === void 0 ? void 0 : _d.url}/token/${token.address}`, target: "_blank", children: _jsx(ScanIcon, { fontSize: "inherit" }) }) }), _jsx(Tooltip, { title: `View chart`, children: _jsx(IconButton, { size: "small", component: "a", href: `${CHART_LINK[token.chainId]}${useWrappedAddress(token.address, token.chainId)}`, target: "_blank", children: _jsx(CandlestickChartIcon, { fontSize: "inherit" }) }) })] }), !isSol && (_jsx(Tooltip, { title: "Taxes on buy and sell transactions can vary. For the most up-to-date information about a token's transaction taxes, visit the project's website and check the contract.", children: _jsx(Chip, { sx: {
                                        mt: 0.5,
                                    }, label: _jsxs("span", { children: [" Taxes ", taxDisplayValue || '-', " %"] }), size: "small", variant: "outlined" }) }))] }), _jsx(TokenSparkLine, { token: token })] }), _jsx(Box, { flexGrow: "1", children: _jsx(Grid, { container: true, spacing: {
                        xs: 0.5,
                        sm: 1,
                    }, justifyContent: "space-evenly", children: (isSol ? solInfoList : infoList).map((info) => (_jsx(Grid, { item: true, xs: 3, children: _jsxs(Stack, { border: 1, borderColor: "action.selected", borderRadius: 1, p: 0.5, alignItems: "center", justifyContent: "center", children: [_jsx(Typography, { color: "primary", variant: "caption", align: "center", fontSize: {
                                        xs: '0.6rem',
                                        sm: '0.75em',
                                    }, children: info.label }), _jsx(Typography, { variant: "caption", align: "center", children: info.value || '-' })] }) }, info.label))) }) }), shortDescriptionMod ? (_jsx(Typography, { pt: 0.5, variant: "caption", lineHeight: 1.5, overflow: "auto", flexGrow: "1", children: shortDescriptionMod })) : (_jsx(Box, { flexGrow: "1", children: _jsx(Alert, { severity: "warning", variant: "outlined", sx: { py: 0 }, children: _jsx(Typography, { variant: "caption", lineHeight: 1, children: "This token is unvetted and trading it is at your own risk. If you buy it, you might not be able to sell it back. Remember, anyone can create tokens, including fake and scam ones." }) }) })), goPlusInfo && (_jsx(Box, { flexGrow: "1", children: _jsxs(Stack, { border: 1, borderColor: "action.selected", borderRadius: 1, direction: "row", pl: 1, alignItems: "center", justifyContent: "space-between", children: [_jsx("img", { src: GoPlusImageSrc, width: 70, alt: "GoPlus" }), _jsx(Typography, { variant: "caption", lineHeight: 1, children: goPlusScore }), _jsx(Button, { variant: "contained", size: "small", sx: {
                                borderTopLeftRadius: 0,
                                borderBottomLeftRadius: 0,
                            }, onClick: () => {
                                openModal('goPlus', {
                                    goPlusInfo,
                                });
                            }, children: _jsx(Typography, { variant: "caption", fontWeight: "bold", children: "Fully Security Report" }) })] }) })), (website || (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.discord) || (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.twitter) || (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.telegram) || (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.youtube)) && (_jsxs(Stack, { children: [_jsx(Typography, { align: "center", variant: "caption", children: "Website and Socials" }), _jsxs(Stack, { direction: "row", justifyContent: "center", spacing: 2, children: [website ? (_jsx(Tooltip, { title: "Website", children: _jsx(Link, { href: website, target: "_blank", children: _jsx(Language, { color: "action", fontSize: "small" }) }) })) : undefined, (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.discord) && (_jsx(Tooltip, { title: "Discord", children: _jsx(Link, { href: socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.twitter, target: "_blank", children: _jsx(DiscordIcon, { color: "action", fontSize: "small" }) }) })), (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.twitter) && (_jsx(Tooltip, { title: "Twitter", children: _jsx(Link, { href: socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.twitter, target: "_blank", children: _jsx(X, { color: "action", fontSize: "small" }) }) })), (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.telegram) && (_jsx(Tooltip, { title: "Telegram", children: _jsx(Link, { href: socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.telegram, target: "_blank", children: _jsx(Telegram, { color: "action", fontSize: "small" }) }) })), (socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.youtube) && (_jsx(Tooltip, { title: "Youtube", children: _jsx(Link, { href: socialLinks === null || socialLinks === void 0 ? void 0 : socialLinks.youtube, target: "_blank", children: _jsx(YouTube, { color: "action", fontSize: "small" }) }) }))] })] }))] }));
});
//# sourceMappingURL=TokenInfo.js.map