import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { memo, useMemo } from 'react';
import { SparkLineChart } from '@mui/x-charts/SparkLineChart';
import useMarketChartData from '../../hooks/useMarketChartData';
import { getFormattedAmount } from '../../utils';
import BigNumber from 'bignumber.js';
import { Box, useTheme } from '@mui/material';
export const TokenSparkLine = memo(({ token }) => {
    const marketChartData = useMarketChartData(token);
    const theme = useTheme();
    const processedData = useMemo(() => {
        if (!(marketChartData === null || marketChartData === void 0 ? void 0 : marketChartData.prices)) {
            return null;
        }
        const times = marketChartData.prices.map(([unixTime]) => new Date(unixTime));
        const prices = marketChartData.prices.map(([, usdPrice]) => usdPrice);
        return {
            times,
            prices,
        };
    }, [marketChartData]);
    if (!processedData) {
        return null;
    }
    return (_jsx(Box, { flexGrow: "1", children: _jsx(SparkLineChart, { colors: [theme.palette.primary.main], data: processedData.prices, height: 50, valueFormatter: (value) => `$ ${getFormattedAmount(new BigNumber(value), 4)}`, xAxis: {
                scaleType: 'time',
                data: processedData.times,
                valueFormatter: (value) => {
                    const dtDate = value.toLocaleDateString();
                    const dtTime = value.toLocaleTimeString();
                    return (_jsxs("span", { children: [dtDate, _jsx("br", {}), dtTime] }));
                },
            }, showTooltip: true, showHighlight: true }) }));
});
//# sourceMappingURL=TokenSparkLine.js.map