import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useTokenList } from '../../hooks/useTokenList';
import React from 'react';
import { ListItem, Stack, styled, Typography, useMediaQuery } from '@mui/material';
import { FixedSizeList } from 'react-window';
import { ETH } from '../../utils/multichain';
import { isAddress } from '../../utils';
import { TokenSelectorListItemSkeleton, TokenSelectorListItem } from './TokenSelectorListItem';
import { useConfig } from '../../providers/ConfigProviders';
import { EMPTY_LIST } from '../../utils/constants';
import { useActiveWeb3React } from '../../hooks/useActiveWeb3React';
export const TokenSelectorList = React.memo(({ search, selectedTokenAddress, onSelect }) => {
    const tokenListMap = useTokenList();
    const smHeight = useMediaQuery('(max-height: 550px)');
    const { chainId } = useActiveWeb3React();
    const [config] = useConfig();
    const tokenAddrList = React.useMemo(() => {
        if (!tokenListMap)
            return EMPTY_LIST;
        const isSearchAddress = isAddress(search, chainId);
        if (isSearchAddress) {
            return [isSearchAddress];
        }
        // move ETH to the top
        const loweredEthAddr = ETH[chainId].address.toLowerCase();
        const eth = tokenListMap[loweredEthAddr];
        const newTokenMap = Object.assign({}, tokenListMap);
        delete newTokenMap[loweredEthAddr];
        const hideTokens = new Set(((config === null || config === void 0 ? void 0 : config.hideTokens) || []).map((s) => s.toLowerCase()));
        const showTokens = new Set(((config === null || config === void 0 ? void 0 : config.showTokens) || []).map((s) => s.toLowerCase()));
        let list = Object.values(newTokenMap).filter((t) => {
            const loweredSymbol = t.symbol.toLowerCase();
            if (hideTokens.has(loweredSymbol) || (showTokens.size > 0 && !showTokens.has(loweredSymbol))) {
                return false;
            }
            return true;
        });
        list.sort((a, b) => a.name.localeCompare(b.name));
        if (eth)
            list.unshift(eth);
        if (search) {
            const loweredSearch = search.toLowerCase();
            list = list.filter(({ name, symbol }) => {
                return symbol.toLowerCase().includes(loweredSearch) || name.toLowerCase().includes(loweredSearch);
            });
        }
        return list.map((token) => token.address);
    }, [tokenListMap, chainId, search, config === null || config === void 0 ? void 0 : config.hideTokens, config === null || config === void 0 ? void 0 : config.showTokens]);
    const renderRow = React.useCallback((props) => {
        const { index, style, isScrolling } = props;
        const address = tokenAddrList[index];
        return (_jsx(ListItem, { style: style, component: "div", disablePadding: true, children: _jsx(TokenSelectorListItem, { selectedTokenAddress: selectedTokenAddress, address: address, isScrolling: Boolean(isScrolling), onSelect: onSelect }) }, address));
    }, [tokenAddrList, selectedTokenAddress, onSelect]);
    return (_jsx(Stack, { spacing: 3, overflow: "auto", children: !tokenAddrList ? (_jsxs(_Fragment, { children: [_jsx(TokenSelectorListItemSkeleton, {}), _jsx(TokenSelectorListItemSkeleton, {}), _jsx(TokenSelectorListItemSkeleton, {}), _jsx(TokenSelectorListItemSkeleton, {}), _jsx(TokenSelectorListItemSkeleton, {})] })) : tokenAddrList.length > 0 ? (_jsx(FixedSizeList, { height: smHeight ? 400 : 500, itemSize: 75, itemCount: tokenAddrList.length, width: "100%", children: renderRow })) : (_jsx(StyledEmptyContainer, { children: _jsx(Typography, { color: "textSecondary", children: "No results found..." }) })) }));
});
const StyledEmptyContainer = styled('div')({
    height: 200,
    display: 'flex',
    justifyContent: 'center',
    paddingTop: 100,
});
//# sourceMappingURL=TokenSelectorList.js.map