var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import React from 'react';
import { CircularProgress, ListItemButton, Stack, styled, Typography, DialogContent } from '@mui/material';
import { useAuth } from '../../hooks/useAuth';
import { injectedConnector, metaMaskConnector, coinbaseConnector, walletConnectConnector } from '../../wagmiUtil';
import { CoinbaseWalletIcon, MetaMaskIcon, TrustWalletIcon, WalletConnectIcon } from '../Icons';
import AccountBalanceWalletIcon from '@mui/icons-material/AccountBalanceWallet';
import { ModalHeader } from '../ModalHeader';
import { useConfig } from '../../providers/ConfigProviders';
const StyledWalletButton = styled(ListItemButton)(({ theme }) => ({
    padding: '1rem',
    margin: '0.5rem 0',
    borderRadius: theme.shape.borderRadius,
    backgroundColor: theme.palette.action.hover,
    '&:hover': {
        backgroundColor: theme.palette.action.selected,
    },
}));
const createWallets = (config) => {
    var _a, _b, _c, _d;
    const showWalletConnect = config.showWalletConnect !== undefined ? config.showWalletConnect : true;
    const wallets = [
        {
            id: metaMaskConnector.id,
            name: metaMaskConnector.name,
            title: 'Metamask',
            icon: MetaMaskIcon,
            installed: typeof window !== 'undefined' && Boolean((_a = window.ethereum) === null || _a === void 0 ? void 0 : _a.isMetaMask) && metaMaskConnector.ready,
            deepLink: `https://metamask.app.link/dapp/${window.location.host}/`,
        },
        {
            id: injectedConnector.id,
            title: 'Trust Wallet',
            icon: TrustWalletIcon,
            installed: typeof window !== 'undefined' &&
                !((_b = window.ethereum) === null || _b === void 0 ? void 0 : _b.isSafePal) && // SafePal has isTrust flag
                (Boolean((_c = window.ethereum) === null || _c === void 0 ? void 0 : _c.isTrust) ||
                    // @ts-ignore
                    Boolean((_d = window.ethereum) === null || _d === void 0 ? void 0 : _d.isTrustWallet)),
            deepLink: `https://link.trustwallet.com/open_url?coin_id=20000714&url=${window.location.href}/`,
        },
        {
            id: coinbaseConnector.id,
            name: coinbaseConnector.name,
            title: 'Coinbase Wallet',
            icon: CoinbaseWalletIcon,
        },
        {
            id: walletConnectConnector.id,
            name: walletConnectConnector.name,
            title: 'Wallet Connect',
            icon: WalletConnectIcon,
        },
    ];
    if (!showWalletConnect) {
        return wallets.filter((wallet) => wallet.id !== walletConnectConnector.id);
    }
    const hasInjected = typeof window !== 'undefined';
    if (hasInjected &&
        injectedConnector.ready &&
        !wallets.some((w) => w.installed && (w.id === injectedConnector.id || w.name === injectedConnector.name))) {
        wallets.unshift({
            id: injectedConnector.id,
            name: injectedConnector.name,
            title: 'Injected',
            icon: AccountBalanceWalletIcon,
        });
    }
    return wallets;
};
export const WalletConnectModal = ({ onClose }) => {
    const { login } = useAuth();
    const [onConnecting, setOnConnection] = React.useState(false);
    const [config] = useConfig();
    const wallets = React.useMemo(() => createWallets(config), [config]);
    return (_jsxs(_Fragment, { children: [_jsx(ModalHeader, { title: " Connect Wallet", onClose: onClose }), _jsx(DialogContent, { className: "thedefiengine-connect-wallet-modal", children: onConnecting ? (_jsxs(Stack, { justifyContent: "center", mt: "2rem", alignItems: "center", textAlign: "center", children: [_jsx(CircularProgress, { size: "90px" }), _jsx("br", {}), _jsx(Typography, { variant: "h6", children: "Waiting to connect" }), _jsx(Typography, { children: "Confirm this connection in your wallet" })] })) : (_jsx(Stack, { children: wallets.map((wallet, i) => {
                        return (_jsx(StyledWalletButton, { onClick: () => __awaiter(void 0, void 0, void 0, function* () {
                                if (wallet.installed || !wallet.deepLink) {
                                    setOnConnection(true);
                                    const connected = yield login(wallet.id);
                                    if (connected) {
                                        onClose();
                                    }
                                    else {
                                        setOnConnection(false);
                                    }
                                }
                                else {
                                    window.open(wallet.deepLink);
                                }
                            }), children: _jsxs(Stack, { direction: "row", spacing: 2, justifyContent: "space-between", alignItems: "center", width: "100%", children: [_jsx(Typography, { fontSize: "large", fontWeight: "500", textTransform: "capitalize", children: wallet.title }), _jsx(wallet.icon, { fontSize: "large", color: "action" })] }) }, i));
                    }) })) })] }));
};
//# sourceMappingURL=WalletConnectModal.js.map