import { useWeb3React } from '../wagmiUtil';
import { useProvider } from 'wagmi';
import { useChainConfig } from '../providers/ConfigProviders';
import { useMemo } from 'react';
import { truncateHash } from '../utils/index';
import { useWallet } from '@solana/wallet-adapter-react';
import { isSolChain } from '../utils/chainIdUtil';
/**
 * Provides a web3 provider with or without user's signer
 * Recreate web3 instance only if the provider change
 */
export const useActiveWeb3React = () => {
    var _a;
    const web3React = useWeb3React();
    const solanaWallet = useWallet();
    const [{ chainId, isReady }] = useChainConfig();
    const isSol = isSolChain(chainId);
    const chain = web3React.chain;
    const walletChainId = isSol ? chainId : chainId && (chain === null || chain === void 0 ? void 0 : chain.id);
    const isNotMatched = Boolean(walletChainId && chainId !== walletChainId);
    const isWrongNetwork = ((_a = chain === null || chain === void 0 ? void 0 : chain.unsupported) !== null && _a !== void 0 ? _a : false) || isNotMatched;
    const provider = useProvider({ chainId: Number(chainId) });
    const account = useMemo(() => {
        var _a;
        if (isSol) {
            return (_a = solanaWallet.publicKey) === null || _a === void 0 ? void 0 : _a.toString();
        }
        return web3React.account;
    }, [isSol, solanaWallet.publicKey, web3React.account]);
    const maskedAccount = useMemo(() => {
        if (!account) {
            return '';
        }
        return truncateHash(account, 2, 4);
    }, [account]);
    return Object.assign(Object.assign({ provider }, web3React), { account,
        maskedAccount, solanaWallet: solanaWallet, chainId,
        isWrongNetwork,
        isNotMatched,
        walletChainId,
        isReady });
};
//# sourceMappingURL=useActiveWeb3React.js.map