var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useCallback, useEffect, useState } from 'react';
import { toast } from 'react-toastify';
import { ConnectorNotFoundError, SwitchChainError, SwitchChainNotSupportedError, useConnect, useDisconnect, } from 'wagmi';
import { useActiveWeb3React } from './useActiveWeb3React';
import { useWallet } from '@solana/wallet-adapter-react';
import { isSolChain } from '../utils/chainIdUtil';
const connectorLocalStorageKey = 'thedefiengine_connector_key';
/**
 * get wallet login and logout handlers
 */
export const useAuth = () => {
    const { connectAsync, connectors } = useConnect();
    const { disconnectAsync } = useDisconnect();
    const { chainId, isReady } = useActiveWeb3React();
    const { disconnect: disconnectSolWallet, wallet, wallets, connect, select } = useWallet();
    const [connectingSolanaWallet, setConnectingSolanaWallet] = useState(false);
    useEffect(() => {
        if ((wallet === null || wallet === void 0 ? void 0 : wallet.adapter) && connectingSolanaWallet) {
            connect()
                .catch((err) => {
                if ((err === null || err === void 0 ? void 0 : err.name) !== 'WalletConnectionError') {
                    toast.error('Failed to connect wallet');
                }
            })
                .finally(() => {
                setConnectingSolanaWallet(false);
            });
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [connectingSolanaWallet]);
    const login = useCallback(
    // eslint-disable-next-line consistent-return
    (targetConnectorID_1, ...args_1) => __awaiter(void 0, [targetConnectorID_1, ...args_1], void 0, function* (targetConnectorID, showError = true) {
        var _a, _b, _c, _d, _e;
        const connectorID = targetConnectorID !== null && targetConnectorID !== void 0 ? targetConnectorID : (_a = window === null || window === void 0 ? void 0 : window.localStorage) === null || _a === void 0 ? void 0 : _a.getItem(connectorLocalStorageKey);
        if (!connectorID) {
            return;
        }
        if (isSolChain(chainId)) {
            const selectedWallet = wallets.find((w) => w.adapter.name === connectorID);
            // if targetConnectorID is provided, it means user is trying to connect wallet from UI manually
            // in that case we allow user to connect regardless of wallet state
            // else that means auto connect is happening, so we only allow to connect if wallet is installed
            if (targetConnectorID ? selectedWallet : (selectedWallet === null || selectedWallet === void 0 ? void 0 : selectedWallet.readyState) === 'Installed') {
                (_b = window === null || window === void 0 ? void 0 : window.localStorage) === null || _b === void 0 ? void 0 : _b.setItem(connectorLocalStorageKey, connectorID);
                select(connectorID);
                setConnectingSolanaWallet(true);
            }
            return;
        }
        const findConnector = connectors.find((c) => c.id.toLowerCase() === connectorID.toLowerCase());
        if (!findConnector) {
            return;
        }
        try {
            const connected = yield connectAsync({ connector: findConnector, chainId: Number(chainId) });
            if (targetConnectorID)
                (_c = window === null || window === void 0 ? void 0 : window.localStorage) === null || _c === void 0 ? void 0 : _c.setItem(connectorLocalStorageKey, connectorID);
            return connected;
        }
        catch (error) {
            (_d = window === null || window === void 0 ? void 0 : window.localStorage) === null || _d === void 0 ? void 0 : _d.removeItem(connectorLocalStorageKey);
            if (showError && !((_e = error === null || error === void 0 ? void 0 : error.message) === null || _e === void 0 ? void 0 : _e.includes('Connection request reset'))) {
                if (error instanceof ConnectorNotFoundError) {
                    toast.error('Connector not found');
                }
                else if (error instanceof SwitchChainNotSupportedError || error instanceof SwitchChainError) {
                    toast.error('Unable to switch network. Please try it on your wallet');
                }
                else if (error.code !== 4001) {
                    toast.error('Unable to connect to the wallet');
                }
            }
        }
    }), [chainId, connectors, wallets, select, connectAsync]);
    const logout = useCallback(() => __awaiter(void 0, void 0, void 0, function* () {
        var _f;
        try {
            if (isSolChain(chainId)) {
                yield disconnectSolWallet();
            }
            else {
                yield disconnectAsync();
            }
        }
        catch (error) {
            console.error(error);
        }
        finally {
            (_f = window === null || window === void 0 ? void 0 : window.localStorage) === null || _f === void 0 ? void 0 : _f.removeItem(connectorLocalStorageKey);
        }
    }), [disconnectAsync, chainId, disconnectSolWallet]);
    return { login, logout, chainId, connectingSolanaWallet, isReady };
};
//# sourceMappingURL=useAuth.js.map