import React from 'react';
import { isEth } from '../utils';
import { BIG_ZERO } from '../utils/constants';
import { useWalletBalance } from './useWalletBalance';
import { useActiveWeb3React } from './useActiveWeb3React';
/**
 * Check the wallet balance of a token
 * @param token The token to get the balance of
 * @param amount The amount to check against the balance
 * @returns
 */
export const useBalanceStatus = (token, amount) => {
    const balance = useWalletBalance(token);
    const { chainId } = useActiveWeb3React();
    return React.useMemo(() => {
        if (!token || !balance) {
            return {
                isEnoughBalance: false,
                maxBalance: BIG_ZERO,
                loaded: false,
            };
        }
        // used to ensure the user doesn't send so much ETH so they end up with <.01
        const maxBalance = isEth(token === null || token === void 0 ? void 0 : token.address, chainId) ? balance.minus(0.01) : balance;
        return {
            isEnoughBalance: amount.isLessThanOrEqualTo(balance),
            maxBalance: maxBalance.gte(0) ? maxBalance : BIG_ZERO,
            loaded: true,
        };
    }, [balance, amount, token]);
};
//# sourceMappingURL=useBalanceStatus.js.map