import { WETH } from './../utils/multichain';
import { useMemo } from 'react';
import { getContract } from '../utils';
import { OFF_CHAIN_ORACLE_ADDRESS } from '../utils/multichain';
import { useActiveWeb3React } from './useActiveWeb3React';
import OffChainOracleABI from '../abi/OffChainOracle.json';
import { useProviderOrSigner } from './useProviderOrSigner';
import ERC20Abi from '../abi/erc20.json';
import WETHAbi from '../abi/weth.json';
import pairAbi from '../abi/pair.json';
import { useProvider } from 'wagmi';
/**
 * get the contract that fetch price
 */
export const useOffChainOracleContract = () => {
    const { chainId } = useActiveWeb3React();
    const provider = useProvider({ chainId: Number(chainId) });
    const oracleContract = useMemo(() => {
        return getContract(OFF_CHAIN_ORACLE_ADDRESS[chainId], OffChainOracleABI, provider, chainId);
    }, [chainId, provider]);
    return oracleContract;
};
/**
 * Get ERC20 token contract
 * @param address The address of the token
 * @param withSignerIfPossible Whether to use a signer if possible
 */
export const useERC20 = (address, withSignerIfPossible = true) => {
    const providerOrSigner = useProviderOrSigner(withSignerIfPossible);
    return useMemo(() => (!address ? null : getContract(address, ERC20Abi, providerOrSigner)), [address, providerOrSigner]);
};
/**
 * Get WETH token contract
 * @param address The address of the token
 * @param withSignerIfPossible Whether to use a signer if possible
 */
export const useWETH = (chainId, withSignerIfPossible = true) => {
    const providerOrSigner = useProviderOrSigner(withSignerIfPossible);
    return useMemo(() => (!WETH[chainId] ? null : getContract(WETH[chainId].address, WETHAbi, providerOrSigner)), [chainId, providerOrSigner]);
};
/**
 * Get Pair token contract
 * @param address The address of the pair contract
 * @param withSignerIfPossible Whether to use a signer if possible
 */
export const usePair = (address, withSignerIfPossible = false) => {
    const providerOrSigner = useProviderOrSigner(withSignerIfPossible);
    return useMemo(() => (!address ? null : getContract(address, pairAbi, providerOrSigner)), [address, providerOrSigner]);
};
//# sourceMappingURL=useContract.js.map