import { useQuery } from '@tanstack/react-query';
import BigNumber from 'bignumber.js';
import { formatUnits } from 'ethers/lib/utils';
import { ChainId, EMPTY_LIST } from '../utils/constants';
import { useActiveWeb3React } from './useActiveWeb3React';
import { isSolChain } from '../utils/chainIdUtil';
export const useGasPrice = () => {
    const { chainId, provider } = useActiveWeb3React();
    const { data } = useQuery(['gasPrice', chainId], () => provider.getGasPrice().then((e) => {
        const gasPrice = new BigNumber(e._hex).toString();
        const gwei = new BigNumber(formatUnits(gasPrice, 'gwei')).decimalPlaces(2).toString();
        return [gasPrice, gwei];
    }), {
        enabled: !isSolChain(chainId),
        refetchOnMount: false,
        refetchOnWindowFocus: true,
        refetchInterval: chainId === ChainId.POLYGON ? 0 : 1000 * 30, // refetch every 30s
    });
    return data || EMPTY_LIST;
};
//# sourceMappingURL=useGasPrice.js.map