import { useQuery } from '@tanstack/react-query';
import BigNumber from 'bignumber.js';
import { formatUnits } from 'ethers/lib/utils';
import { useActiveWeb3React } from './useActiveWeb3React';
import { isSolChain } from '../utils/chainIdUtil';
import { useGasConfig } from '../providers/GasConfigProvider';
import { useMemo } from 'react';
export const useGasPriceV2 = () => {
    const { chainId, provider } = useActiveWeb3React();
    const [gasConfig] = useGasConfig();
    const { data } = useQuery(['gasPriceV2', chainId], () => provider.getGasPrice().then((e) => {
        const gasPriceInBigNumber = new BigNumber(e._hex);
        const standard = gasPriceInBigNumber;
        const fast = gasPriceInBigNumber.times(1.05).decimalPlaces(0);
        const lightspeed = gasPriceInBigNumber.times(1.1).decimalPlaces(0);
        return {
            gwei: {
                standard: new BigNumber(formatUnits(standard.toString(), 'gwei')).decimalPlaces(2).toString(),
                fast: new BigNumber(formatUnits(fast.toString(), 'gwei')).decimalPlaces(2).toString(),
                lightspeed: new BigNumber(formatUnits(lightspeed.toString(), 'gwei')).decimalPlaces(2).toString(),
            },
            gasPrice: {
                standard: standard.toString(),
                fast: fast.toString(),
                lightspeed: lightspeed.toString(),
            },
        };
    }), {
        enabled: !isSolChain(chainId),
        refetchOnMount: false,
        refetchOnWindowFocus: true,
        refetchInterval: 1000 * 30, // refetch every 30s
    });
    const adjustedData = useMemo(() => {
        if (!data) {
            return '';
        }
        return data.gasPrice[gasConfig];
    }, [data, gasConfig]);
    return [adjustedData, data];
};
//# sourceMappingURL=useGasPriceV2.js.map