var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { hasFeeUrl } from './../utils/constants';
import { useQuery } from 'wagmi';
import { isCustomChain } from '../utils/chainIdUtil';
const TOKEN_FEE_CACHE = {};
const fetchTaxFeeCheck = (chainId, tokens) => __awaiter(void 0, void 0, void 0, function* () {
    const addressesToFetch = [];
    for (const token of tokens) {
        if (token) {
            // return true if token has transaction fee
            if (token.hasTransactonFees === true || token.hasTransactionFees === true) {
                return true;
            }
            const cached = TOKEN_FEE_CACHE[`${chainId}-${token.address}`];
            if (cached !== undefined) {
                // return true if it's already known to have fee through cache
                if (cached) {
                    return true;
                }
            }
            // if the token doesnt have the fee info, add it to the list to fetch
            if (token.hasTransactonFees === undefined && token.hasTransactionFees === undefined) {
                addressesToFetch.push(token.address);
            }
        }
    }
    // return false if all tokens are known and has no fee
    if (!addressesToFetch.length) {
        return false;
    }
    // check if any unknown tokens has fee
    return fetch(hasFeeUrl, {
        method: 'POST',
        body: JSON.stringify({
            chainId,
            addresses: addressesToFetch,
        }),
        headers: {
            'x-api-key': window.theDefiEngineApiKey,
        },
    }).then((res) => __awaiter(void 0, void 0, void 0, function* () {
        if (res.ok) {
            const data = yield res.json();
            if (data) {
                let anyHasFee = false;
                // update cache
                for (const addr in data) {
                    TOKEN_FEE_CACHE[`${chainId}-${addr}`] = data[addr];
                    if (data[addr]) {
                        anyHasFee = true;
                    }
                }
                // return true if any token has fee
                return anyHasFee;
            }
        }
        // if failed to fetch, return true to be safe
        return true;
    }));
});
const useHasFees = (chainId, tokens) => {
    const isPc = isCustomChain(chainId);
    const { data } = useQuery(['fetchTaxFeeCheck', tokens], () => fetchTaxFeeCheck(chainId, tokens), {
        retry: false,
        refetchOnWindowFocus: false,
        refetchOnMount: false,
        refetchOnReconnect: false,
        cacheTime: 10000000000,
        staleTime: 10000000000,
        keepPreviousData: false,
        // only enable if there are tokens and it's a pet chain
        enabled: Boolean(tokens.length && isPc),
    });
    // return false if it's not a pet chain
    if (!isPc) {
        return false;
    }
    return data;
};
export default useHasFees;
//# sourceMappingURL=useHasFees.js.map