var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import BigNumber from 'bignumber.js';
import { useQuery } from '@tanstack/react-query';
import { isSolChain } from '../utils/chainIdUtil';
const fetchJupiterPrice = (mint, signal) => {
    return fetch(`https://price.jup.ag/v4/price?ids=${mint}`, {
        signal,
    })
        .then((response) => __awaiter(void 0, void 0, void 0, function* () {
        var _a, _b;
        const data = yield response.json();
        if (response.ok && ((_b = (_a = data === null || data === void 0 ? void 0 : data.data) === null || _a === void 0 ? void 0 : _a[mint]) === null || _b === void 0 ? void 0 : _b.price)) {
            return new BigNumber(data.data[mint].price);
        }
        return null;
    }))
        .catch(() => {
        return null;
    });
};
const INTERVAL = 1000 * 30; // every 30 seconds
export const useJupiterPrice = (mint, chainId) => {
    var _a;
    const isSol = isSolChain(chainId);
    const result = useQuery(['jupiter-price', 'price', mint], ({ signal }) => fetchJupiterPrice(mint, signal), {
        enabled: Boolean(mint && isSol),
        refetchOnWindowFocus: true,
        refetchInterval: INTERVAL,
        keepPreviousData: false,
        refetchOnMount: false,
        staleTime: INTERVAL,
        cacheTime: INTERVAL,
    });
    if (!isSol) {
        return null;
    }
    return (_a = result === null || result === void 0 ? void 0 : result.data) !== null && _a !== void 0 ? _a : null;
};
//# sourceMappingURL=useJupiterPrice.js.map