import { useMemo } from 'react';
import { useAccount, useProvider, useSigner } from 'wagmi';
import { useActiveWeb3React } from './useActiveWeb3React';
/**
 * Get provider or signer
 * @param withSignerIfPossible Whether to use a signer if possible
 * @return The provider or signer
 */
export const useProviderOrSigner = (withSignerIfPossible = true) => {
    const { chainId } = useActiveWeb3React();
    const provider = useProvider({ chainId: Number(chainId) });
    const { address, isConnected } = useAccount();
    const { data: signer } = useSigner();
    return useMemo(() => (withSignerIfPossible && address && isConnected && signer ? signer : provider), [address, isConnected, provider, signer, withSignerIfPossible]);
};
//# sourceMappingURL=useProviderOrSigner.js.map