import { isSolChain } from '../utils/chainIdUtil';
import { useQuery } from 'wagmi';
import { SOL_ADDR } from '../utils/multichain';
import { useConnection } from '@solana/wallet-adapter-react';
import { PublicKey } from '@solana/web3.js';
const useSolMarketData = (token) => {
    const { connection } = useConnection();
    const { data } = useQuery(['useSolMarketData', token], () => {
        if (token.address === SOL_ADDR) {
            return connection.getSupply().then((totalSupply) => {
                return {
                    totalSupply: totalSupply.value.total / Math.pow(10, token.decimals),
                };
            });
        }
        return connection.getTokenSupply(new PublicKey(token.address)).then((totalSupply) => {
            return {
                totalSupply: totalSupply.value.uiAmount,
            };
        });
    }, {
        refetchOnMount: false,
        refetchOnReconnect: false,
        refetchOnWindowFocus: false,
        enabled: Boolean(token && isSolChain(token.chainId)),
    });
    return data;
};
export default useSolMarketData;
//# sourceMappingURL=useSolMarketData.js.map