import BigNumber from 'bignumber.js';
import React from 'react';
import { getBalanceAmount } from '../utils';
/**
 * Get derived amount for a input token
 * @param shouldUseQuotePrice whether to use the quote price or the swap state price
 * @param stateAmount the amount in the swap state
 * @param quoteAmount the amount in the quote
 * @param inputToken the input token
 * @returns
 */
export const useDerivedAmount = (shouldUseQuotePrice, stateAmount, quoteAmount, inputToken) => {
    return React.useMemo(() => {
        if (quoteAmount && shouldUseQuotePrice && inputToken) {
            const amountInBG = getBalanceAmount(new BigNumber(quoteAmount), inputToken === null || inputToken === void 0 ? void 0 : inputToken.decimals);
            return [amountInBG, amountInBG.precision(8).toString()];
        }
        return [new BigNumber(stateAmount || 0), stateAmount];
    }, [inputToken, quoteAmount, stateAmount, shouldUseQuotePrice]);
};
//# sourceMappingURL=useSwapDerivedAmount.js.map