var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
/* eslint-disable consistent-return */
import { useCallback, useMemo } from 'react';
import { toast } from 'react-toastify';
import { useAccount, useSwitchNetwork as useSwitchNetworkWallet } from 'wagmi';
import { useChainConfig } from '../providers/ConfigProviders';
import { walletConnectConnector } from '../wagmiUtil';
import { isSolChain } from '../utils/chainIdUtil';
import { useActiveWeb3React } from './useActiveWeb3React';
/**
 * get switch network related variables
 */
export const useSwitchNetwork = () => {
    const _a = useSwitchNetworkWallet(), { switchNetworkAsync: _switchNetworkAsync, isLoading } = _a, switchNetworkArgs = __rest(_a, ["switchNetworkAsync", "isLoading"]);
    const { chainId: currentChainId } = useActiveWeb3React();
    const { isConnected, connector } = useAccount();
    const [, setChainConfig] = useChainConfig();
    const switchNetworkAsync = useCallback((chainId) => __awaiter(void 0, void 0, void 0, function* () {
        if (isConnected &&
            typeof _switchNetworkAsync === 'function' &&
            !isSolChain(chainId) &&
            !isSolChain(currentChainId)) {
            if (isLoading)
                return;
            return _switchNetworkAsync(chainId)
                .then(() => {
                setChainConfig((c) => (Object.assign(Object.assign({}, c), { chainId })));
                return true;
            })
                .catch(() => {
                toast.error('Error connecting, please retry and confirm in wallet!');
            });
        }
        setChainConfig((c) => (Object.assign(Object.assign({}, c), { chainId })));
        return true;
    }), [isConnected, _switchNetworkAsync, setChainConfig, isLoading, currentChainId]);
    const canSwitch = useMemo(() => {
        var _a, _b;
        return isConnected
            ? !!_switchNetworkAsync &&
                connector.id !== walletConnectConnector.id &&
                !(typeof window !== 'undefined' &&
                    // @ts-ignore
                    (((_a = window.ethereum) === null || _a === void 0 ? void 0 : _a.isSafePal) || ((_b = window.ethereum) === null || _b === void 0 ? void 0 : _b.isMathWallet)))
            : true;
    }, [_switchNetworkAsync, isConnected, connector]);
    return Object.assign(Object.assign({}, switchNetworkArgs), { switchNetworkAsync,
        isLoading,
        canSwitch });
};
//# sourceMappingURL=useSwitchNetwork.js.map