var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getContract, isAddress } from '../utils';
import { CG_CHAIN_ID } from '../utils/multichain';
import { useActiveWeb3React } from './useActiveWeb3React';
import ERC20_ABI from '../abi/erc20.json';
import ERC20_BYTES32_ABI from '../abi/erc20_bytes32.json';
import { useTokenList } from './useTokenList';
import { useEffect, useMemo, useRef } from 'react';
import { useQuery } from '@tanstack/react-query';
import { useNativeAddress } from './useNativeAddress';
import { isSolChain } from '../utils/chainIdUtil';
import { solTokenListUrl } from '../utils/constants';
/**
 * Get the token information using token address
 * @param address The address of the token
 * @returns The token information
 */
export const useToken = (address) => {
    const { chainId } = useActiveWeb3React();
    const isSol = isSolChain(chainId);
    const tokenList = useTokenList();
    const chainIdRef = useRef(chainId);
    const tokenAddress = useNativeAddress(address === null || address === void 0 ? void 0 : address.trim(), chainId);
    useEffect(() => {
        // this prevent fetch when chain id change but token address have not yet yet
        chainIdRef.current = chainId;
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [tokenAddress]);
    const tokenListToken = useMemo(() => {
        if (!tokenAddress || !tokenList) {
            return undefined;
        }
        return tokenList[tokenAddress === null || tokenAddress === void 0 ? void 0 : tokenAddress.toLowerCase()];
    }, [tokenAddress, tokenList]);
    const { data } = useQuery(['tokenInfo', tokenAddress], ({ signal }) => isSol
        ? fetch(`${solTokenListUrl}?address=${tokenAddress}`, {
            signal,
            headers: {
                'x-api-key': window.theDefiEngineApiKey,
            },
        })
            .then((r) => r.json())
            .then((res) => {
            var _a;
            if (!res.token.symbol || !res.token.name || !res.token.decimals) {
                throw new Error('Invalid token from Jupiter');
            }
            const tokenInfo = {
                chainId: chainId,
                address: tokenAddress,
                name: res === null || res === void 0 ? void 0 : res.token.name,
                symbol: (_a = res === null || res === void 0 ? void 0 : res.token.symbol) === null || _a === void 0 ? void 0 : _a.toUpperCase(),
                decimals: res === null || res === void 0 ? void 0 : res.token.decimals,
                render: 'swap',
                vetted: undefined,
                website: undefined,
                logoURI: res === null || res === void 0 ? void 0 : res.token.logoURI,
            };
            return tokenInfo;
        })
            .catch((ex) => __awaiter(void 0, void 0, void 0, function* () {
            console.error(ex);
            return undefined;
        }))
        : fetch(`https://api.coingecko.com/api/v3/coins/${CG_CHAIN_ID[chainId]}/contract/${tokenAddress}`, {
            signal,
        })
            .then((r) => r.json())
            .then((res) => {
            var _a, _b, _c, _d, _e, _f;
            const decimals = (_b = (_a = res === null || res === void 0 ? void 0 : res.detail_platforms) === null || _a === void 0 ? void 0 : _a[CG_CHAIN_ID[chainId]]) === null || _b === void 0 ? void 0 : _b.decimal_place;
            if (!res.symbol || !res.name || !decimals) {
                throw new Error('Invalid token from CG');
            }
            const tokenInfo = {
                chainId: chainId,
                address: tokenAddress,
                name: res === null || res === void 0 ? void 0 : res.name,
                symbol: (_c = res === null || res === void 0 ? void 0 : res.symbol) === null || _c === void 0 ? void 0 : _c.toUpperCase(),
                decimals,
                render: 'swap',
                vetted: undefined,
                website: (_e = (_d = res === null || res === void 0 ? void 0 : res.links) === null || _d === void 0 ? void 0 : _d.homepage) === null || _e === void 0 ? void 0 : _e[0],
                logoURI: (_f = res === null || res === void 0 ? void 0 : res.image) === null || _f === void 0 ? void 0 : _f.small,
            };
            return tokenInfo;
        })
            .catch((ex) => __awaiter(void 0, void 0, void 0, function* () {
            // fallback to use contract to fetch token info
            console.error(ex);
            const tokenContract = getContract(tokenAddress, ERC20_ABI, undefined, chainId);
            const tokenContractBytes32 = getContract(tokenAddress, ERC20_BYTES32_ABI, undefined, chainId);
            const decimals = yield tokenContract.decimals();
            if (decimals) {
                const handleComplete = ([name, symbol]) => {
                    if (name && symbol) {
                        return {
                            chainId: chainId,
                            address: tokenAddress,
                            decimals,
                            symbol,
                            name,
                        };
                    }
                    return undefined;
                };
                return Promise.all([tokenContract.name(), tokenContract.symbol()])
                    .then(handleComplete)
                    .catch(() => {
                    return Promise.all([tokenContractBytes32.name(), tokenContractBytes32.symbol()]).then(handleComplete);
                });
            }
            return undefined;
        })), {
        refetchOnMount: false,
        refetchOnReconnect: false,
        refetchOnWindowFocus: false,
        keepPreviousData: false,
        enabled: Boolean(tokenList && !tokenListToken && chainIdRef.current === chainId && isAddress(tokenAddress, chainId) && chainId),
    });
    return tokenListToken || data;
};
//# sourceMappingURL=useToken.js.map