import { useERC20 } from './useContract';
import { useQuery } from '@tanstack/react-query';
import BigNumber from 'bignumber.js';
import { getBalanceAmount, isEth } from '../utils';
import { useActiveWeb3React } from './useActiveWeb3React';
/**
 * Get the allowance of a token
 * @param token The token to get the balance of
 * @param account The account address
 * @param spender The spender contract address
 * @returns The allowance of the token in BigNumber (decimal parsed). Returns null if empty or loading
 */
export const useTokenAllowance = (token, account, spender) => {
    const contract = useERC20(token === null || token === void 0 ? void 0 : token.address, false);
    const { chainId } = useActiveWeb3React();
    const enabled = Boolean(token && !isEth(token.address, chainId) && account && spender);
    const { data } = useQuery(['allowance', token, account, spender], () => contract.allowance(account, spender).then((bg) => getBalanceAmount(new BigNumber(bg._hex), token.decimals)), {
        enabled,
        refetchOnMount: false,
        refetchOnReconnect: false,
        refetchOnWindowFocus: false,
        keepPreviousData: false,
    });
    return enabled ? data : null;
};
//# sourceMappingURL=useTokenAllowance.js.map