var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { useMemo } from 'react';
import { tokenListUrl } from '../utils/constants';
import { useQuery } from '@tanstack/react-query';
import { useActiveWeb3React } from './useActiveWeb3React';
import { useConfig } from '../providers/ConfigProviders';
/**
 * Get the token list for a chain
 * @returns The token list for the current chain, null if list is still fetching
 */
export const useTokenList = () => {
    const { chainId } = useActiveWeb3React();
    const [config] = useConfig();
    const { data } = useQuery(['tokenlist'], () => fetch(tokenListUrl).then((res) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        if (!res.ok)
            throw new Error('Failed to fetch token list');
        const data = yield res.json();
        const mapped = data.tokens.reduce((tokenMap, _a) => {
            var { chains } = _a, tokenInfo = __rest(_a, ["chains"]);
            Object.entries(chains).forEach(([, { chainId: tokenChainId, address, scanLink, decimals }]) => {
                var _a;
                if (address && Number(tokenChainId)) {
                    const token = Object.assign(Object.assign({}, tokenInfo), { chainId: tokenChainId, address,
                        scanLink, decimals: decimals || tokenInfo.decimals });
                    if (!tokenMap[tokenChainId]) {
                        tokenMap[tokenChainId] = {};
                    }
                    const loweredAddr = address.toLowerCase();
                    if (!((_a = tokenMap[tokenChainId]) === null || _a === void 0 ? void 0 : _a[loweredAddr])) {
                        tokenMap[tokenChainId][loweredAddr] = token;
                    }
                }
            });
            return tokenMap;
        }, {});
        (_a = config.predefinedTokens) === null || _a === void 0 ? void 0 : _a.forEach((token) => {
            var _a;
            if (!mapped[token.chainId]) {
                mapped[token.chainId] = {};
            }
            const lowered = token.address.toLowerCase();
            if (!((_a = mapped[token.chainId]) === null || _a === void 0 ? void 0 : _a[lowered])) {
                mapped[token.chainId][lowered] = token;
            }
        });
        return mapped;
    })), {
        refetchOnMount: false,
        refetchOnReconnect: false,
        refetchOnWindowFocus: false,
    });
    return useMemo(() => (data ? data[chainId] : undefined), [chainId, data]);
};
//# sourceMappingURL=useTokenList.js.map