import React from 'react';
import { isEth } from '../utils';
/**
 * Return Wrap, Unwrap, or empty string based on the input and output token
 *
 * @param inputToken The input token
 * @param outputToken The output token
 * @returns Wrap, Unwrap, or empty string
 */
export const useWrapOrUnwrap = (inputToken, outputToken, chainId) => {
    return React.useMemo(() => {
        // if input is ETH and output is not ETH
        if (isEth(inputToken === null || inputToken === void 0 ? void 0 : inputToken.address, chainId) && (outputToken === null || outputToken === void 0 ? void 0 : outputToken.symbol) === `W${inputToken === null || inputToken === void 0 ? void 0 : inputToken.symbol}`) {
            return 'Wrap';
        }
        else if (isEth(outputToken === null || outputToken === void 0 ? void 0 : outputToken.address, chainId) && (inputToken === null || inputToken === void 0 ? void 0 : inputToken.symbol) === `W${outputToken === null || outputToken === void 0 ? void 0 : outputToken.symbol}`) {
            return 'Unwrap';
        }
        return undefined;
    }, [chainId, inputToken === null || inputToken === void 0 ? void 0 : inputToken.address, inputToken === null || inputToken === void 0 ? void 0 : inputToken.symbol, outputToken === null || outputToken === void 0 ? void 0 : outputToken.address, outputToken === null || outputToken === void 0 ? void 0 : outputToken.symbol]);
};
//# sourceMappingURL=useWrapOrUnwrap.js.map