import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import { useSwapState } from './SwapStateProvider';
import { useActiveWeb3React } from '../hooks/useActiveWeb3React';
import { useConfig } from './ConfigProviders';
import { useSlippage } from './SlippageProvider';
import { getDecimalAmount, isEth } from '../utils';
import { isKyberChain, isSolChain } from '../utils/chainIdUtil';
import BigNumber from 'bignumber.js';
import { queryClient } from '../utils/queryClient';
import { useToken } from '../hooks/useToken';
import useHasFees from '../hooks/useHasFees';
import { useWrapOrUnwrap } from '../hooks/useWrapOrUnwrap';
const AggregatorQuoteParamsContext = React.createContext(null);
export const AggregatorQuoteParamsProvider = ({ children }) => {
    const [swapState] = useSwapState();
    const [quoteParams, setQuoteParams] = React.useState(null);
    const inputToken = useToken(swapState === null || swapState === void 0 ? void 0 : swapState.sellTokenAddress);
    const outputToken = useToken(swapState === null || swapState === void 0 ? void 0 : swapState.buyTokenAddress);
    const { chainId } = useActiveWeb3React();
    const [config] = useConfig();
    const [slippage] = useSlippage();
    const wrapOrUnWrap = useWrapOrUnwrap(inputToken, outputToken, chainId);
    const hasFeeOnTransfer = useHasFees(chainId, [inputToken, outputToken]);
    React.useEffect(() => {
        if (inputToken &&
            outputToken &&
            ((swapState.type === 'SELL' && Number(swapState.inputAmount)) ||
                (swapState.type === 'BUY' && Number(swapState.outputAmount)))) {
            const timeoutId = setTimeout(() => {
                var _a, _b;
                const params = {
                    sellToken: isEth(inputToken.address, chainId) && !isSolChain(chainId) && !isKyberChain(chainId)
                        ? inputToken.symbol
                        : inputToken.address,
                    buyToken: isEth(outputToken.address, chainId) && !isSolChain(chainId) && !isKyberChain(chainId)
                        ? outputToken.symbol
                        : outputToken.address,
                    slippagePercentage: (Number(slippage) || 0) / 100 + 0.0001, // buffer
                    hasFeeOnTransfer,
                    chainId: chainId,
                    wrapOrUnWrap,
                };
                if (swapState.type === 'SELL' && Number(swapState.inputAmount)) {
                    params.sellAmount = getDecimalAmount(new BigNumber(swapState.inputAmount), inputToken === null || inputToken === void 0 ? void 0 : inputToken.decimals).toJSON();
                }
                else if (swapState.type === 'BUY' && Number(swapState.outputAmount)) {
                    params.buyAmount = getDecimalAmount(new BigNumber(swapState.outputAmount), outputToken === null || outputToken === void 0 ? void 0 : outputToken.decimals).toJSON();
                }
                const affiliateFeeRecipient = (_b = (_a = config.affiliateFeeRecipientByChains) === null || _a === void 0 ? void 0 : _a[chainId]) !== null && _b !== void 0 ? _b : config.affiliateFeeRecipient;
                if ((isSolChain(chainId) || !hasFeeOnTransfer) && config.affiliateFee && affiliateFeeRecipient) {
                    params.feeRecipient = affiliateFeeRecipient;
                    params.buyTokenPercentageFee = Number(config.affiliateFee) / 100;
                }
                setQuoteParams(params);
            }, 300);
            return () => {
                clearTimeout(timeoutId);
            };
        }
        else {
            queryClient.removeQueries(['aggregator-api']);
            setQuoteParams(null);
        }
    }, [
        chainId,
        hasFeeOnTransfer,
        inputToken,
        outputToken,
        swapState.inputAmount,
        swapState.outputAmount,
        swapState.type,
        slippage,
        config.affiliateFee,
        config.affiliateFeeRecipient,
        config.affiliateFeeRecipientByChains,
        wrapOrUnWrap,
    ]);
    return _jsx(AggregatorQuoteParamsContext.Provider, { value: quoteParams, children: children });
};
export const useAggregatorQuoteParams = () => React.useContext(AggregatorQuoteParamsContext);
//# sourceMappingURL=AggregatorQuoteParamsProvider.js.map