import { jsx as _jsx } from "react/jsx-runtime";
import React, { useRef } from 'react';
import { ChainId } from '../utils/constants';
import { CHAINS } from '../utils/multichain';
const chainIdStorageKey = 'thedefiengine-selected-chain-id';
const ConfigContext = React.createContext(null);
const ChainConfigContext = React.createContext(null);
const getChainConfig = (options, isReady) => {
    return {
        chainId: options.chainId || ChainId.POLYGON,
        allowedChainIds: new Set(options.allowedChainIds || CHAINS.map((c) => c.id)),
        isReady: Boolean(isReady || options.disabledPersistSelectedChain),
    };
};
export const ConfigProvider = ({ children, options }) => {
    const configStateActions = React.useState(options);
    const chainConfigStateActions = React.useState(() => getChainConfig(options));
    const [configState, setConfigState] = configStateActions;
    const [chainConfigState, setChainConfigState] = chainConfigStateActions;
    React.useEffect(() => {
        if (typeof window !== 'undefined') {
            window.theDefiEngineApiKey = options.apiKey;
        }
    }, [options.apiKey]);
    React.useEffect(() => {
        if (configState !== options &&
            // deep compare
            JSON.stringify(configState) !== JSON.stringify(options)) {
            setConfigState(options);
            setChainConfigState(getChainConfig(options, true));
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [options]);
    const initRef = useRef(false);
    React.useEffect(() => {
        if (!configState.disabledPersistSelectedChain) {
            if (chainConfigState.chainId && initRef.current) {
                window.localStorage.setItem(chainIdStorageKey, String(chainConfigState.chainId));
            }
            else {
                const persistChainId = parseInt(String(window.localStorage.getItem(chainIdStorageKey)));
                setChainConfigState((s) => (Object.assign(Object.assign({}, s), { chainId: persistChainId || configState.chainId || ChainId.POLYGON, isReady: true })));
                initRef.current = true;
            }
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [chainConfigState.chainId, configState.disabledPersistSelectedChain, setChainConfigState]);
    return (_jsx(ConfigContext.Provider, { value: configStateActions, children: _jsx(ChainConfigContext.Provider, { value: chainConfigStateActions, children: children }) }));
};
export const useConfig = () => React.useContext(ConfigContext);
export const useChainConfig = () => React.useContext(ChainConfigContext);
//# sourceMappingURL=ConfigProviders.js.map