import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { GlobalStyles, ThemeProvider } from '@mui/material';
import { createTheme } from '@mui/material/styles';
import { blueGrey } from '@mui/material/colors';
import { useOverrides } from './OverrideProvider';
import { toastifyCss } from '../utils/cssStr';
export const defaultTheme = {
    primaryColor: '#2196f3',
    primaryColorDark: '#8ec9ff',
    secondaryColor: blueGrey[600],
    secondaryColorDark: blueGrey[100],
    primaryTextColor: 'rgba(0, 0, 0, 0.87)',
    primaryTextColorDark: '#ffffff',
    secondaryTextColor: blueGrey[600],
    secondaryTextColorDark: blueGrey[100],
    cardBackgroundColor: '#ffffff',
    cardBackgroundColorDark: '#121212',
    backgroundColor: '#ffffff',
    backgroundColorDark: '#121212',
    borderRadius: 10,
    fontSize: 14,
    fontFamily: 'Roboto, Helvetica, Arial, sans-serif',
};
const getTheme = (theme, themeOptionsConfig) => {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const isDark = ((_a = theme === null || theme === void 0 ? void 0 : theme.palette) === null || _a === void 0 ? void 0 : _a.mode) === 'dark';
    const themeOptions = Object.assign({}, defaultTheme);
    Object.entries(themeOptionsConfig).forEach(([key, value]) => {
        if (value !== undefined) {
            themeOptions[key] = value;
        }
    });
    let borderRadius = themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.borderRadius;
    if (typeof borderRadius === 'string') {
        borderRadius = Number(borderRadius.replace('px', ''));
    }
    let fontSize = themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.fontSize;
    if (typeof fontSize === 'string') {
        fontSize = Number(fontSize.replace('px', ''));
    }
    return createTheme(Object.assign(Object.assign({}, theme), { palette: Object.assign(Object.assign({}, theme === null || theme === void 0 ? void 0 : theme.palette), { background: {
                paper: isDark ? themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.cardBackgroundColorDark : themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.cardBackgroundColor,
                default: isDark ? themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.backgroundColorDark : themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.backgroundColor,
            }, primary: Object.assign({ main: isDark ? themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.primaryColorDark : themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.primaryColor }, (_b = theme === null || theme === void 0 ? void 0 : theme.palette) === null || _b === void 0 ? void 0 : _b.primary), secondary: Object.assign({ main: isDark ? themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.secondaryColorDark : themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.secondaryColor }, (_c = theme === null || theme === void 0 ? void 0 : theme.palette) === null || _c === void 0 ? void 0 : _c.secondary), text: Object.assign({ primary: isDark ? themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.primaryTextColorDark : themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.primaryTextColor, secondary: isDark ? themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.secondaryTextColorDark : themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.secondaryTextColor }, (_d = theme === null || theme === void 0 ? void 0 : theme.palette) === null || _d === void 0 ? void 0 : _d.text) }), typography: Object.assign({ button: {
                textTransform: 'none',
            }, fontSize: fontSize, fontFamily: themeOptions === null || themeOptions === void 0 ? void 0 : themeOptions.fontFamily }, theme === null || theme === void 0 ? void 0 : theme.typography), shape: Object.assign({ borderRadius: borderRadius }, theme === null || theme === void 0 ? void 0 : theme.shape), components: Object.assign({ MuiButton: {
                styleOverrides: {
                    root: {
                        borderRadius: (_f = (_e = theme === null || theme === void 0 ? void 0 : theme.shape) === null || _e === void 0 ? void 0 : _e.borderRadius) !== null && _f !== void 0 ? _f : borderRadius,
                        outline: 'none !important',
                    },
                },
            }, MuiInputBase: {
                styleOverrides: {
                    input: {
                        outline: 'none !important',
                    },
                },
            }, MuiDialog: {
                styleOverrides: {
                    paper: {
                        borderRadius: (_h = (_g = theme === null || theme === void 0 ? void 0 : theme.shape) === null || _g === void 0 ? void 0 : _g.borderRadius) !== null && _h !== void 0 ? _h : borderRadius,
                        margin: 0,
                        width: '100%',
                    },
                },
            }, MuiPaper: {
                styleOverrides: {
                    root: {
                        backgroundImage: 'none',
                    },
                },
            }, MuiTooltip: {
                defaultProps: {
                    arrow: true,
                },
            } }, theme === null || theme === void 0 ? void 0 : theme.components) }));
};
export const CustomThemeProvider = ({ enableDarkMode, primaryColor, primaryColorDark, secondaryColor, secondaryColorDark, primaryTextColor, primaryTextColorDark, secondaryTextColorDark, secondaryTextColor, fontFamily, borderRadius, fontSize, backgroundColor, cardBackgroundColor, backgroundColorDark, cardBackgroundColorDark, disableThemeProvider, children, }) => {
    const overrides = useOverrides();
    const [muiLightTheme, muiDarkTheme] = React.useMemo(() => {
        var _a;
        const options = {
            primaryColor,
            primaryColorDark,
            secondaryColor,
            secondaryColorDark,
            primaryTextColor,
            primaryTextColorDark,
            secondaryTextColor,
            secondaryTextColorDark,
            fontFamily,
            borderRadius,
            fontSize,
            backgroundColor,
            cardBackgroundColor,
            backgroundColorDark,
            cardBackgroundColorDark,
        };
        return [
            getTheme(overrides === null || overrides === void 0 ? void 0 : overrides.MuiThemeLight, options),
            getTheme(Object.assign(Object.assign({}, overrides === null || overrides === void 0 ? void 0 : overrides.MuiThemeDark), { palette: Object.assign({ mode: 'dark' }, (_a = overrides === null || overrides === void 0 ? void 0 : overrides.MuiThemeDark) === null || _a === void 0 ? void 0 : _a.palette) }), options),
        ];
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [
        overrides,
        primaryColor,
        primaryColorDark,
        secondaryColor,
        secondaryColorDark,
        primaryTextColor,
        primaryTextColorDark,
        secondaryTextColor,
        secondaryTextColorDark,
        fontFamily,
        borderRadius,
        fontSize,
        backgroundColor,
        cardBackgroundColor,
        backgroundColorDark,
        cardBackgroundColorDark,
    ]);
    if (disableThemeProvider) {
        return children;
    }
    return (_jsxs(ThemeProvider, { theme: enableDarkMode ? muiDarkTheme : muiLightTheme, children: [_jsx(GlobalStyles, { styles: {
                    '& .thedefiengine-swap-card input::-webkit-outer-spin-button, input::-webkit-inner-spin-button': {
                        appearance: 'none',
                        margin: 0,
                    },
                    '& .thedefiengine-svg': {
                        verticalAlign: 'text-top',
                    },
                    '& html': {
                        WebkitTapHighlightColor: 'transparent',
                    },
                    '& body': {
                        '--w3m-z-index': 100000,
                    },
                    '& .thedefiengine-swap-card input': {
                        outline: 'none !important',
                    },
                    '& .thedefiengine-swap-card button': {
                        outline: 'none !important',
                    },
                    '& #walletconnect-qrcode-modal': {
                        visibility: 'visible !important',
                    },
                } }), _jsx(GlobalStyles, { styles: toastifyCss }), overrides.GlobalStyles && _jsx(GlobalStyles, { styles: overrides.GlobalStyles }), children] }));
};
//# sourceMappingURL=CustomThemeProvider.js.map