import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import { useConfig } from './ConfigProviders';
const GasConfigProviderContext = React.createContext(null);
export const gasConfigProviderStorageKey = `thedefiengine-gasConfig`;
export const GasConfigProvider = ({ children }) => {
    const [config] = useConfig();
    const [gasConfig, setGasConfig] = React.useState('standard');
    React.useEffect(() => {
        if (config.hideGasConfigButton) {
            return;
        }
        const storedItemJson = localStorage.getItem(gasConfigProviderStorageKey);
        try {
            if (storedItemJson) {
                const storedItem = JSON.parse(storedItemJson);
                if (storedItem) {
                    setGasConfig(storedItem);
                    return;
                }
            }
        }
        catch (_a) {
            localStorage.removeItem(gasConfigProviderStorageKey);
        }
    }, [config.hideGasConfigButton]);
    const contextVal = React.useMemo(() => [
        gasConfig,
        (newGasConfig) => {
            localStorage.setItem(gasConfigProviderStorageKey, JSON.stringify(newGasConfig));
            setGasConfig(newGasConfig);
        },
    ], [gasConfig]);
    return _jsx(GasConfigProviderContext.Provider, { value: contextVal, children: children });
};
export const useGasConfig = () => React.useContext(GasConfigProviderContext);
//# sourceMappingURL=GasConfigProvider.js.map