import { BoxProps, ButtonProps, FabProps, InputProps, PaperProps, StackProps, ThemeOptions, TypographyProps } from '@mui/material';
import React from 'react';
import { NumericFormatProps } from 'react-number-format';
import { ToastContainerProps } from 'react-toastify';
export interface Overrides {
    /**
     * Swap card title, accept any react component or string
     */
    SwapCardTitle?: React.ReactNode;
    /**
     * Swap route card title, accept any react component or string
     */
    SwapRouteCardTitle?: React.ReactNode;
    /**
     * Price comparison card title, accept any react component or string
     */
    PriceComparisonCardTitle?: React.ReactNode;
    /**
     * react-tostify container props
     * docs: https://fkhadra.github.io/react-toastify/api/toast-container/
     */
    ToastContainer?: ToastContainerProps;
    /**
     * docs: https://mui.com/api/button/
     */
    ConnectionInfoButton?: ButtonProps;
    /**
     * docs: https://www.npmjs.com/package/react-number-format
     * docs: https://mui.com/material-ui/api/input/
     */
    SlippageInput?: NumericFormatProps<InputProps>;
    /**
     * Style applied to all SwapCard, SwapRouteCard, TokenInfoCard, and PriceComparisonCard
     * docs: https://mui.com/api/paper/
     */
    Card?: PaperProps;
    /**
     * Style applied to the card title container of all SwapCard, SwapRouteCard, TokenInfoCard, and PriceComparisonCard
     * docs: https://mui.com/api/stack/
     */
    CardTitleContainer?: StackProps;
    /**
     * docs: https://mui.com/api/paper/
     */
    SwapCard?: PaperProps;
    /**
     * docs: https://mui.com/api/paper/
     */
    SwapRouteCard?: PaperProps;
    /**
     * docs: https://mui.com/api/paper/
     */
    TokenInfoCard?: PaperProps;
    /**
     * docs: https://mui.com/api/paper/
     */
    PriceComparisonCard?: PaperProps;
    /**
     * docs: https://mui.com/api/typography/
     */
    ModalHeader?: TypographyProps;
    /**
     * docs: https://mui.com/api/fab/
     */
    SwitchSwapButton?: FabProps;
    /**
     * docs: https://mui.com/api/button/
     */
    ConfirmSwapButton?: ButtonProps;
    /**
     * docs: https://mui.com/api/button/
     */
    ApproveButton?: ButtonProps;
    /**
     * docs: https://mui.com/api/button/
     */
    WalletConnectButton?: ButtonProps;
    /**
     * docs: https://mui.com/material-ui/api/box/
     */
    SwapInputContainer?: BoxProps;
    /**
     * docs: https://www.npmjs.com/package/react-number-format
     */
    SwapInput?: NumericFormatProps;
    /**
     * The mui theme options for the light theme
     * @see https://mui.com/material-ui/customization/theming/ for customization
     */
    MuiThemeLight?: ThemeOptions;
    /**
     * The mui theme options for the dark theme
     * @see https://mui.com/material-ui/customization/theming/ for customization
     */
    MuiThemeDark?: ThemeOptions;
    /**
     * Global styles to be applied to the app
     */
    GlobalStyles?: string;
}
/**
 * Override colors and other component props (e.g. make wallet connect button bigger or change color). Can be used side by side with theme options
 */
export declare const OverrideProvider: ({ children, ...overridesOptions }: React.PropsWithChildren<Overrides>) => import("react/jsx-runtime").JSX.Element;
export declare const useOverrides: () => Overrides;
//# sourceMappingURL=OverrideProvider.d.ts.map