import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import { ChainId, EMPTY_LIST } from '../utils/constants';
import { ETH, ETH_ADDR } from '../utils/multichain';
const PinnedTokenContext = React.createContext(null);
const defaultState = Object.values(ChainId).reduce((acc, v) => {
    if (typeof v === 'number') {
        acc[v] = [ETH_ADDR];
    }
    return acc;
}, {});
export const pinnedTokenStorageKey = `thedefiengine-pinned-tokens`;
export const PinnedTokenProvider = ({ children, defaultPinnedTokens, }) => {
    const [state, setState] = React.useState(defaultState);
    React.useEffect(() => {
        const storagedItemJson = localStorage.getItem(pinnedTokenStorageKey);
        try {
            if (storagedItemJson) {
                const storagedItem = JSON.parse(storagedItemJson);
                if (storagedItem) {
                    setState(Object.assign(Object.assign({}, defaultState), storagedItem));
                    return;
                }
            }
        }
        catch (_a) {
            localStorage.removeItem(pinnedTokenStorageKey);
        }
        if (defaultPinnedTokens)
            setState(Object.assign(Object.assign({}, defaultState), defaultPinnedTokens));
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const contextVal = React.useMemo(() => {
        const hashedState = Object.values(ChainId).reduce((acc, chainId) => {
            if (typeof chainId === 'number' && state[chainId]) {
                acc[chainId] = state[chainId] ? new Set(state[chainId].map((a) => a.toLowerCase())) : new Set();
            }
            return acc;
        }, {});
        return [
            state,
            (tokenAddr, chainId) => {
                if (!tokenAddr || !chainId)
                    return false;
                if (!hashedState[chainId]) {
                    return tokenAddr.toLowerCase() === ETH[chainId].address.toLowerCase();
                }
                return hashedState[chainId].has(tokenAddr.toLowerCase());
            },
            (tokenAddr, chainId) => {
                var _a, _b, _c;
                const lowered = tokenAddr.toLowerCase();
                const isExist = (_b = (_a = state[chainId]) === null || _a === void 0 ? void 0 : _a.some((t) => t.toLowerCase() === lowered)) !== null && _b !== void 0 ? _b : false;
                const newState = Object.assign(Object.assign({}, state), { [chainId]: isExist
                        ? state[chainId].filter((t) => t.toLowerCase() !== lowered)
                        : [...((_c = state[chainId]) !== null && _c !== void 0 ? _c : EMPTY_LIST), lowered] });
                localStorage.setItem(pinnedTokenStorageKey, JSON.stringify(newState));
                setState(newState);
            },
        ];
    }, [state]);
    return _jsx(PinnedTokenContext.Provider, { value: contextVal, children: children });
};
export const usePinnedTokenContext = () => React.useContext(PinnedTokenContext) || [];
//# sourceMappingURL=PinnedTokenProvider.js.map