import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import { useActiveWeb3React } from '../hooks/useActiveWeb3React';
import { useConfig } from './ConfigProviders';
import { ETH, ETH_ADDR } from '../utils/multichain';
import { useSwitchNetworkEffect } from '../hooks/useSwitchNetworkEffect';
const SwapStateContext = React.createContext([null, null]);
const defaultSwapState = {
    type: 'SELL',
    loading: false,
    isConfirming: false,
};
const getDefaultSwapState = (config, chainId) => {
    var _a, _b, _c, _d;
    return (Object.assign(Object.assign({}, defaultSwapState), { sellTokenAddress: config.disabledPersistSelectedToken
            ? ((_b = (_a = config.defaultSelectedTokenByChains) === null || _a === void 0 ? void 0 : _a[chainId]) === null || _b === void 0 ? void 0 : _b.defaultInputToken) || ETH[chainId].address
            : undefined, buyTokenAddress: config.disabledPersistSelectedToken
            ? (_d = (_c = config.defaultSelectedTokenByChains) === null || _c === void 0 ? void 0 : _c[chainId]) === null || _d === void 0 ? void 0 : _d.defaultOutputToken
            : undefined }));
};
export const getTokenSelectStorageKey = (type, chainId) => {
    return `TOKEN_${type}_${chainId}`;
};
export const SwapStateProvider = ({ children }) => {
    const [config] = useConfig();
    const { chainId } = useActiveWeb3React();
    const swapStateHandler = React.useState(getDefaultSwapState(config, chainId));
    const [, setState] = swapStateHandler;
    React.useEffect(() => {
        if (!config.disabledPersistSelectedToken) {
            setState((s) => {
                var _a, _b, _c, _d, _e;
                const newState = Object.assign(Object.assign({}, s), { inputAmount: '', outputAmount: '', isConfirming: false, sellTokenAddress: localStorage.getItem(getTokenSelectStorageKey('SELL', chainId)) ||
                        ((_b = (_a = config.defaultSelectedTokenByChains) === null || _a === void 0 ? void 0 : _a[chainId]) === null || _b === void 0 ? void 0 : _b.defaultInputToken) ||
                        ((_c = ETH[chainId]) === null || _c === void 0 ? void 0 : _c.address) ||
                        ETH_ADDR, buyTokenAddress: localStorage.getItem(getTokenSelectStorageKey('BUY', chainId)) ||
                        ((_e = (_d = config.defaultSelectedTokenByChains) === null || _d === void 0 ? void 0 : _d[chainId]) === null || _e === void 0 ? void 0 : _e.defaultOutputToken) });
                if (newState.sellTokenAddress && newState.sellTokenAddress === newState.buyTokenAddress) {
                    newState.buyTokenAddress = '';
                }
                return newState;
            });
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [chainId]);
    useSwitchNetworkEffect((newChainId) => {
        if (config.disabledPersistSelectedToken) {
            setState(getDefaultSwapState(config, newChainId));
        }
    }, [config.disabledPersistSelectedToken]);
    return _jsx(SwapStateContext.Provider, { value: swapStateHandler, children: children });
};
export const useSwapState = () => React.useContext(SwapStateContext);
//# sourceMappingURL=SwapStateProvider.js.map