import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { providers } from 'ethers';
import React from 'react';
import { toast } from 'react-toastify';
import { EMPTY_LIST, EMPTY_OBJECT } from '../utils/constants';
import { CHAINS_MAP } from '../utils/multichain';
import { queryClient } from '../utils/queryClient';
import { useConfig } from './ConfigProviders';
import { Typography } from '@mui/material';
import { useConnection } from '@solana/wallet-adapter-react';
import { isSolChain } from '../utils/chainIdUtil';
export var TransactionStatus;
(function (TransactionStatus) {
    TransactionStatus["Pending"] = "Pending";
    TransactionStatus["Success"] = "Success";
    TransactionStatus["Failed"] = "Failed";
})(TransactionStatus || (TransactionStatus = {}));
const ONE_DAY_IN_MS = 24 * 60 * 60 * 1000;
const TransactionProviderContext = React.createContext(null);
const TransactionUpsertProviderContext = React.createContext(null);
export const transactionProviderStorageKey = `thedefiengine-transactions`;
export const TransactionProvider = ({ children }) => {
    const stateHandler = React.useState(EMPTY_LIST);
    const [transactions, setTransactions] = stateHandler;
    const { connection: solConnection } = useConnection();
    const initedRef = React.useRef(false);
    React.useEffect(() => {
        const storagedItemJson = localStorage.getItem(transactionProviderStorageKey);
        try {
            if (storagedItemJson) {
                const storagedItem = JSON.parse(storagedItemJson);
                if (storagedItem) {
                    setTransactions(storagedItem);
                    initedRef.current = false;
                    return;
                }
            }
        }
        catch (_a) {
            localStorage.removeItem(transactionProviderStorageKey);
        }
    }, [setTransactions]);
    React.useEffect(() => {
        if (initedRef.current) {
            localStorage.setItem(transactionProviderStorageKey, JSON.stringify(transactions));
        }
        else {
            initedRef.current = true;
        }
    }, [transactions]);
    const [config] = useConfig();
    const pendingTransactions = React.useMemo(() => transactions.filter((t) => t.status === TransactionStatus.Pending), [transactions]);
    const handleUpsertTransaction = React.useCallback((transaction) => {
        setTransactions((ts) => {
            const index = ts.findIndex((t) => t.txn === transaction.txn);
            if (index === -1) {
                // max allow 20 transactions history
                return [transaction, ...ts.slice(0, 20)];
            }
            return [...ts.slice(0, index), transaction, ...ts.slice(index + 1)];
        });
    }, [setTransactions]);
    const [checkTransactionCount, setCheckTransactionCount] = React.useState(0);
    const providersRef = React.useRef(EMPTY_OBJECT);
    React.useEffect(() => {
        // check swap transaction status
        if (pendingTransactions.length > 0) {
            const timeoutId = setTimeout(() => {
                const promises = pendingTransactions.map((t) => {
                    const chainId = Number(t.chainId);
                    if (isSolChain(chainId)) {
                        // get sol transaction status
                        return solConnection.getParsedTransaction(t.txn, { maxSupportedTransactionVersion: 1 }).then((r) => {
                            var _a;
                            if (!r) {
                                // mark as failed if transaction is not found after 24 hours
                                if (new Date().getTime() - t.createdAt.getTime() > ONE_DAY_IN_MS) {
                                    return 0;
                                }
                                return null;
                            }
                            // 1 = success, 0 = failed
                            return ((_a = r.meta) === null || _a === void 0 ? void 0 : _a.err) ? 0 : 1;
                        });
                    }
                    if (!providersRef.current[chainId]) {
                        const chain = CHAINS_MAP[chainId];
                        providersRef.current[chainId] = new providers.JsonRpcProvider(chain.rpcUrls.default.http[0], {
                            name: chain.network,
                            chainId: chain.id,
                        });
                    }
                    const provider = providersRef.current[chainId];
                    return provider.getTransactionReceipt(t.txn).then((r) => { var _a; return (r ? (_a = r.status) !== null && _a !== void 0 ? _a : -1 : null); });
                });
                Promise.all(promises).then((statuses) => {
                    statuses.forEach((status, i) => {
                        var _a;
                        if (status !== null) {
                            const transaction = pendingTransactions[i];
                            if (status === 1) {
                                if (transaction.inputToken)
                                    queryClient.invalidateQueries(['walletBalance', transaction.inputToken]);
                                if (transaction.outputToken)
                                    queryClient.invalidateQueries(['walletBalance', transaction.outputToken]);
                                if (transaction.quote)
                                    (_a = config.onSuccessSwap) === null || _a === void 0 ? void 0 : _a.call(config, transaction.quote);
                                toast.success(_jsxs(_Fragment, { children: [_jsx(Typography, { variant: "subtitle2", children: "Transaction completed!" }), _jsx(Typography, { variant: "body2", children: transaction.message })] }));
                                handleUpsertTransaction(Object.assign(Object.assign({}, transaction), { status: TransactionStatus.Success }));
                            }
                            else {
                                handleUpsertTransaction(Object.assign(Object.assign({}, transaction), { status: TransactionStatus.Failed }));
                                toast.error(_jsxs(_Fragment, { children: [_jsx(Typography, { variant: "subtitle2", children: "Transaction failed!" }), _jsx(Typography, { variant: "body2", children: transaction.errorMessage || transaction.message })] }));
                            }
                        }
                    });
                    // trigger again if there is any pending transaction
                    if (statuses.some((r) => r === null)) {
                        setCheckTransactionCount((c) => c + 1);
                    }
                });
            }, 1000);
            return () => {
                clearTimeout(timeoutId);
            };
        }
        else {
            providersRef.current = EMPTY_OBJECT;
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [handleUpsertTransaction, pendingTransactions.length, checkTransactionCount]);
    return (_jsx(TransactionUpsertProviderContext.Provider, { value: handleUpsertTransaction, children: _jsx(TransactionProviderContext.Provider, { value: stateHandler, children: children }) }));
};
export const useTransactions = () => React.useContext(TransactionProviderContext);
export const useUpsertTransaction = () => React.useContext(TransactionUpsertProviderContext);
//# sourceMappingURL=TransactionProvider.js.map