import { ChainId } from './utils/constants';
export type SwapType = 'SELL' | 'BUY';
export interface SwapState {
    sellTokenAddress?: string;
    buyTokenAddress?: string;
    inputAmount?: string;
    outputAmount?: string;
    type: SwapType;
    loading: boolean;
    isConfirming: boolean;
}
export interface AggregatorQuote {
    from?: string;
    to?: string;
    sellTokenAddress?: string;
    buyTokenAddress?: string;
    value?: string;
    chainId: ChainId;
    price?: string;
    guaranteedPrice?: string;
    guaranteedPriceBigTotal?: string;
    buyAmount: string;
    sellAmount: string;
    sources?: AggregatorQuoteLiquiditySource[];
    gasPrice: string;
    gas: string;
    estimatedGas?: string;
    sellTokenToEthRate?: string;
    buyTokenToEthRate?: string;
    sellTokenToUsdRate?: string;
    buyTokenToUsdRate?: string;
    orderRoutes?: AggregatorRoute[];
    orderGraph?: AggregatorRouteGraph;
    protocolFee?: string;
    minimumProtocolFee?: string;
    allowanceTarget?: string;
    orders?: AggregatorQuoteOrder[];
    data?: string;
    priceDiffList?: AggregatorPriceDiff[];
    estimatedPriceImpact?: string | null;
    buyAmountMin?: string;
    sellTokenPrice?: string;
    buyTokenPrice?: string;
    wrapUnwrap?: 'Wrap' | 'Unwrap';
}
export interface AggregatorRouteGraphSource {
    label: string;
    percent: number;
}
export interface AggregatorRouteGraphEdge {
    sources: AggregatorRouteGraphSource[];
    percent: number;
    sourceAddress: string;
    targetAddress: string;
}
export interface AggregatorRouteGraph {
    sources: string[];
    addresses: string[];
    nodes: {
        [sourceAddress: string]: {
            [targetAddress: string]: AggregatorRouteGraphEdge;
        };
    };
}
export interface AggregatorRoute {
    proportion: string;
    paths: string[][];
    sourceName: string;
    isMultihop: boolean;
}
export interface AggregatorPriceDiff {
    diff: string;
    buyAmount: string;
    sellAmount: string;
    source: string;
}
export interface AggregatorQuoteOrder {
    makerToken: string;
    source: string;
    takerToken: string;
    takerAmount: string;
    sourcePathId?: string;
    fillData: {
        router: string;
        tokenAddressPath: string[];
    };
}
export interface AggregatorQuoteLiquiditySource {
    name: string;
    proportion: string;
    intermediateToken?: string;
    hops?: string[];
}
export interface AggregatorQuoteParams {
    sellToken: string;
    buyToken: string;
    sellAmount?: string;
    buyAmount?: string;
    slippagePercentage?: number;
    gasPrice?: string;
    buyTokenPercentageFee?: number;
    feeRecipient?: string;
    takerAddress?: string;
    skipValidation?: boolean;
    includedSources?: string;
    excludedSources?: string;
    alwaysUnmaskPancake?: boolean;
    hasFeeOnTransfer?: boolean;
    chainId?: ChainId;
    wrapOrUnWrap?: 'Wrap' | 'Unwrap';
}
export interface AffiliateData {
    marketer: string;
    affiliateFee: number;
    affiliateFeeRecipient: string;
    affiliateFeeRecipientByChains?: {
        [chainId: number]: string;
    };
}
//# sourceMappingURL=types.d.ts.map