import { Chain } from 'wagmi';
import { ChainIdMap } from './constants';
import { Token } from './token';
/**
 * wagmiChains contains partial specs for the following chains
 *
 * mainnet, ropsten, rinkeby, goerli, kovan, sepolia, optimism, optimismKovan, optimismGoerli,
 * polygon, polygonMumbai, arbitrum, arbitrumRinkeby, arbitrumGoerli, localhost, hardhat, foundr,
 *
 * If existed in wagmiChains. You can {...wagmiChains.[chainName]} to import some of the chain specs,
 */
export interface ExtendedChain extends Chain {
    wrappedTokenAddress: string;
    shortName: string;
    /**
     * coin geico chain id. https://www.coingecko.com/en/api/documentation
     */
    cgChainId: string;
    /**
     * Chain logo url, obtain from https://coinmarketcap.com/chain-ranking/
     */
    logoUrl: string;
    /**
     * For USD price. Contract address obtain from https://github.com/1inch/spot-price-aggregator
     */
    offChainOracleAddress: string;
    aggregator: {
        apiUrl: string;
        proxyAddress: string;
    };
    /**
     * Need at least two stable coins
     */
    stablecoins: {
        address: string;
        decimals: number;
        symbol: string;
    }[];
    chart: string;
}
export declare const polygon: ExtendedChain;
export declare const bsc: ExtendedChain;
export declare const ftm: ExtendedChain;
export declare const eth: ExtendedChain;
export declare const avax: ExtendedChain;
export declare const arb: ExtendedChain;
export declare const op: ExtendedChain;
export declare const base: ExtendedChain;
export declare const zksync: ExtendedChain;
export declare const aurora: ExtendedChain;
export declare const gnosis: ExtendedChain;
export declare const moonriver: ExtendedChain;
export declare const moonbeam: ExtendedChain;
export declare const linea: ExtendedChain;
export declare const fuse: ExtendedChain;
export declare const solana: ExtendedChain;
export declare const boba: ExtendedChain;
export declare const polygonzkEvm: ExtendedChain;
export declare const metis: ExtendedChain;
export declare const cronos: ExtendedChain;
export declare const mantle: ExtendedChain;
export declare const scroll: ExtendedChain;
export declare const blast: ExtendedChain;
/**
 * -------- MAPPING ---------
 */
export declare const CHAINS: ExtendedChain[];
export declare const CHAINS_MAP: ChainIdMap<ExtendedChain>;
export declare const ETH_ADDR = "0xEeeeeEeeeEeEeeEeEeEeeEEEeeeeEeeeeeeeEEeE";
export declare const SOL_ADDR = "So11111111111111111111111111111111111111112";
export declare const METIS_ADDR = "0xdeaddeaddeaddeaddeaddeaddeaddeaddead0000";
export declare const ETH: ChainIdMap<Token>;
export declare const WETH: ChainIdMap<Token>;
export declare const STABLE_COINS: ChainIdMap<Token[]>;
export declare const OFF_CHAIN_ORACLE_ADDRESS: ChainIdMap<string>;
export declare const AGGREGATOR_PROXY_ADDRESS: ChainIdMap<string>;
export declare const BASE_SCAN_INFO: ChainIdMap<{
    name: string;
    url: string;
}>;
export declare const CG_CHAIN_ID: ChainIdMap<string>;
export declare const CHART_LINK: ChainIdMap<string>;
//# sourceMappingURL=multichain.d.ts.map