import { configureChains, createClient } from 'wagmi';
import { MetaMaskConnector } from 'wagmi/connectors/metaMask';
import { jsonRpcProvider } from 'wagmi/providers/jsonRpc';
import { CoinbaseWalletConnector } from 'wagmi/connectors/coinbaseWallet';
import { WalletConnectConnector } from 'wagmi/connectors/walletConnect';
import { CHAINS } from '../utils/multichain';
import { InjectedConnector } from '@wagmi/core';
export const w3mProjectId = '2ead7798bb50c745a4e45187f56661bf';
export const { provider, chains } = configureChains(CHAINS, [
    jsonRpcProvider({
        //rpc: (chain) => ({ http: (chain.id === 1) ? `https://eth.llamarpc.com` : chain.rpcUrls.default.http[0] }),
        rpc: (chain) => ({ http: chain.rpcUrls.default.http[0] }),
    }),
]);
export const injectedConnector = new InjectedConnector({
    chains,
});
export const walletConnectConnector = new WalletConnectConnector({
    chains,
    options: {
        projectId: w3mProjectId,
        showQrModal: true,
        isNewChainsStale: false,
    },
});
export const metaMaskConnector = new MetaMaskConnector({
    chains,
    options: {
        shimDisconnect: false,
    },
});
export const coinbaseConnector = new CoinbaseWalletConnector({
    chains,
    options: {
        appName: 'Aggregator',
        appLogoUrl: 'https://thedefiengine.tech/favicon.ico',
    },
});
export const connectors = [injectedConnector, metaMaskConnector, coinbaseConnector, walletConnectConnector];
export const makeClient = () => {
    const wagmiClient = createClient({
        provider,
        connectors,
    });
    return {
        wagmiClient,
    };
};
export const CHAIN_IDS = chains.map((c) => c.id);
export const isChainSupported = (chainId) => CHAIN_IDS.includes(chainId);
export const isChainTestnet = (chainId) => { var _a; return (_a = chains.find((c) => c.id === chainId)) === null || _a === void 0 ? void 0 : _a.testnet; };
//# sourceMappingURL=wagmi.js.map